/********************************************************************
*  X_DEFS.H
*
*  This header file defines constants for the SORCUS libraries
*  for the MAX-system.
*
*  Copyrights:          SORCUS Computer GmbH 2001
*                       All Rights Reserved
********************************************************************/

#ifndef _INC_X_DEFS_H
#define _INC_X_DEFS_H

#include "x_error.h"

#if defined (_MAKEDLL_) // only defined for generation of the library
   #define MAXAPI __declspec(dllexport)
   #define MAXEXPORT __stdcall
#else
   #ifdef PLATFORM_LINUX
      #define MAXAPI
      #define MAXEXPORT __attribute((__stdcall__))
   #else
      #ifndef _RTLIB_
         #define MAXEXPORT __stdcall
         #define MAXAPI __declspec(dllimport)
      #else
         #define MAXAPI
         #define MAXEXPORT far pascal
      #endif
   #endif
#endif

// cardtypes returned by get_config and max_get_board_info
#ifndef CARDTYPE_MAX6PCI
        #define CARDTYPE_MAX6PCI                0x600
#endif
#ifndef CARDTYPE_XBUS_CPU
   #define CARDTYPE_XBUS_CPU  0x010
#endif
#ifndef CARDTYPE_ML2
        #define CARDTYPE_ML2     0x2
#endif
#ifndef CARDTYPE_ML6
        #define CARDTYPE_ML6     0x6
#endif
#ifndef CARDTYPE_ML7
        #define CARDTYPE_ML7     0x7
#endif
#ifndef CARDTYPE_ML8
        #define CARDTYPE_ML8     0x8
#endif
#ifndef CARDTYPE_XCPUMODULE
   #define CARDTYPE_XCPUMODULE   0x0010
#endif
#ifndef CARDTYPE_XKIT3
   #define CARDTYPE_XKIT3        0x0300
#endif
#ifndef CARDTYPE_SIDIP
   #define CARDTYPE_SIDIP        0x0500
#endif
#ifndef CARDTYPE_MAX5DIP
   #define CARDTYPE_MAX5DIP      0x0500
#endif
#ifndef CARDTYPE_MAX8DIP
   #define CARDTYPE_MAX8DIP      0x00F0
#endif
#ifndef CARDTYPE_MAXBOX
   #define CARDTYPE_MAXBOX       0x00F3
#endif
#ifndef CARDTYPE_CANBOX
   #define CARDTYPE_CANBOX       0x00F4
#endif
#ifndef CARDTYPE_SODIP
   #define CARDTYPE_SODIP        0x0400
#endif
#ifndef CARDTYPE_UNKNOWN
   #define CARDTYPE_UNKNOWN      0xFFFF
#endif

#define MAX_SLOTNUMBER                                255  // highest X-Bus-Slot number


// definitions for module types and corresponding MDD-program numbers
#define MODULE_TYPE_X_MAX_1		 11
#define MDD_X_MAX_1		         0x800B
#define MODULE_TYPE_X_MAX_E      12
#define MDD_X_MAX_E		         0x800C
#define MODULE_TYPE_X_MAX_400    14
#define MDD_X_MAX_400	         0x800E
#define MODULE_TYPE_X_REL_8		16
#define MDD_X_REL_8		         0x8010
#define MODULE_TYPE_X_AD24_4		20
#define MDD_X_AD24_4		         0x8014
#define MODULE_TYPE_X_AD24_4I		20
#define MDD_X_AD24_4I		         0x8014
#define MODULE_TYPE_X_OPT_200		24
#define MDD_X_OPT_200	         0x8018
#define MODULE_TYPE_X_OPT_164		25
#define MDD_X_OPT_164	         0x8019
#define MODULE_TYPE_X_OPT_128		26
#define MDD_X_OPT_128	         0x801A
#define MODULE_TYPE_X_OPT_812		27
#define MDD_X_OPT_812	         0x801B
#define MODULE_TYPE_X_OPT_416		28
#define MDD_X_OPT_416	         0x801C
#define MODULE_TYPE_X_OPT_020		29
#define MDD_X_OPT_020	         0x801D
#define MODULE_TYPE_X_AD16_4		32
#define MDD_X_AD16_4					0x8020
#define MODULE_TYPE_X_AD14_20		36
#define MDD_X_AD14_20	         0x8024
#define MODULE_TYPE_X_DIO_40		40
#define MODULE_TYPE_X_DIO_32		40
#define MODULE_SUBTYPE_X_DIO_40  0
#define MODULE_SUBTYPE_X_DIO_40I 1
#define MODULE_SUBTYPE_X_DIO_32  2
#define MDD_X_DIO_40			      0x8028
#define MDD_X_DIO_32		         0x8028
#define MODULE_TYPE_X_5BX64_8		42
#define MDD_X_5BX64_8	         0x802A
#define MODULE_TYPE_X_CPLD38		43
#define MDD_X_CPLD_38	         0x802B
#define MODULE_TYPE_X_DAD_4U		44
#define MDD_X_DAD_4U		         0x802C
#define MODULE_TYPE_X_DAD_4I		45
#define MDD_X_DAD_4I		         0x802D
#define MODULE_TYPE_X_5B_1		   46
#define MDD_X_5B_1		         0x802E
#define MODULE_TYPE_X_DA12_4		48
#define MDD_X_DA12_4		         0x8030
#define MODULE_TYPE_X_DA16_4		50
#define MDD_X_DA16_4		         0x8032
#define MDD_X_DA16_4FIFO         0x8132
#define MODULE_TYPE_X_C16_3		54
#define MDD_X_C16_3		         0x8036
#define MODULE_TYPE_X_CAN_2		58
#define MDD_X_CAN_2		         0x803A
#define MODULE_TYPE_X_SSI_2		68
#define MDD_X_SSI_2		         0x8044
#define MODULE_TYPE_X_ETH_10	   81
#define MDD_X_ETH_10		         0x8051
#define MODULE_TYPE_X_COM_4	   82
#define MDD_X_COM_4		         0x8052
#define MODULE_TYPE_X_SCC_2	   84
#define MDD_X_SCC_2              0x8054
#define MODULE_TYPE_X_COM_8		88
#define MDD_X_COM_8              0x8058
#define MODULE_TYPE_X_DPS_2		91
#define MDD_X_DPS_2		         0x805B
#define MODULE_TYPE_X_TEST_1		0x80
#define MDD_X_TEST_1		         0x8080
#define MDD_X_MSG_MDD	         0x8FFF
#define MDD_SIDIP		            0x8500
#define MDD_MAX5DIP	            0x8500
#define MDD_MAX8DIP	            0x85F0


// connection types of a board
#define MAX_LOCAL_CONNECTION		1
#define MAX_SERIAL_CONNECTION		2
#define MAX_SERVER_CONNECTION		3
#define MAX_TCPIP_CONNECTION		4
#define MAX_UNKNOWN_CONNECTION	0xFFFF

// definitions for buffer block access strategy
#define MAX_BUFFER_MOVE_ABS                0x00 // all or nothing
#define MAX_BUFFER_MOVE_MAX                0x01 // as much as possible
#define MAX_BUFFER_COPY_ABS                0x02 // copy from buffer as much as possible
#define MAX_BUFFER_COPY_MAX                0x03 // copy from buffer all or nothing

/* definitions for task type in MAX_PGM_TYPE and flags in MAX_PDT_HEAD */
#define MAX_NI_TASK              0x00
#define MAX_II_TASK              0x01
#define MAX_TI_TASK              0x03

/* definitions for flags in MAX_PDT_HEAD */
#define MAXPDT_TASKTYP_IN_PDT       0x0008
#define MAXPDT_TASKTYPE_IN_PDT      0x0008
#define MAXPDT_DATA_IN_PROG         0x0100
#define MAXPDT_FIXED_DATASIZE       0x0200
#define MAXPDT_PARAMETER_IN_PROG    0x0400

/* definitions for the PDT elements */
#define MAX_CPU486                    4
#define _NOCOPROC                     0
#define _487SX                        3
#define MAXRT_LANGUAGE_ASM            1
#define MAXRT_LANGUAGE_C              10
#define MAXRT_LANGUAGE_PAS            7

/* definitions for the installation flags in in MAX_PGM_TYPE */
#define MAX_CALL_AUTO_INIT            0x0800
#define MAX_AUTO_ACTIVATE             0x1000
#define MAX_TASKTYP_BY_INSTALL        0x0008
#define MAX_TASKTYPE_BY_INSTALL       0x0008
#define MAX_DATASIZE_IN_PDT           0x0600
#define MAX_TASKNO_BY_USER            0x2000
#define MAX_TASKNO_BY_INSTALL         0x2000

/* stategies for memory allocation (used by allocate_ram) */
#define MAX_ALLOC_UP_ABS            1  // BOTTOM UP, all or nothing
#define MAX_ALLOC_UP_MAX            2  // BOTTOM UP, as much as possible
#define MAX_ALLOC_DOWN_ABS          3  // TOP DOWN, all or nothing
#define MAX_ALLOC_DOWN_MAX          4  // TOP DOWN, as much as possible
#ifdef _RTLIB_
   #define MAX_ALLOC_DOS_MEMORY     5  // like ALLOC_UP_ABS but all memory<1MB
#endif

// types of operating system (sco_type_check)
#define MAX_MINI_OSX                0
#define MAX_ROM_OSX                 1
#define MAX_RAM_OSX                 2
#define MAX_WIN_CE_OS               5

// Default search path for OsX file
#define MAX1_NEWEST_OSX             "MAX1-*.*R"
#define MAXE_NEWEST_OSX             "MAXE-*.*R"

// definitions for connect_cpu
#define MAX_MYSELF                  0xFFFF // slot number in a real-time-program
                                    		 // for the slot where the program runs
#define MAX_AUTO_SLOT               0xFFFF // library should detect cpu-module

#define MAX_LOCAL_BOARD             0      // connection to cpu-module on the same board
#define MAX_PCI_HOST                1      // connection to host PC via the PCI interface (on MAXpci only)
#define MAX_SERIAL_HOST             2      // connection to host PC via serial connection
#define MAX_ETHERNET_HOST           4      // connection to host PC via ethernet connection

// definitions for the timer on the CPU module
#define MAX1_TIMER_MODE_INT            2
#define MAX1_TIMER_A                   0
#define MAX1_TIMER_B                   1
#define MAX1_TIMER_C                   2

// definitions for the bits in usFlags in the MAX_TIMER_STATE_TYPE structure
#define MAX_TIMER_OUTPUT					0x80	// actual state of output pin
#define MAX_TIMER_MODE						0x06	// operating mode of the timer
#define MAX_TIMER_ZERO						0x40	// set if counter has run down to 0
#define MAX_TIMER_DECIMAL_COUNT			0x01	// set if decimal counter

// definitions for alarm settings
#define MAX1_CYCLIC_ALARM           	0xFFFF

// definitions for the interrupts on the CPU module
#define MAX1_IRQ_NMI							0x02
#define MAX1_IRQ_TIMERA                0x78
#define MAX1_IRQ_KEYBOARD              0x79
#define MAX1_IRQ_COM2                  0x7B
#define MAX1_IRQ_X6                    0x7C
#define MAX1_IRQ_X7                    0x7D
#define MAX1_IRQ_RBF                   0x7E  // x-bus mailbox
#define MAX1_IRQ_EPP                   0x7F	
#define MAX1_IRQ_RTC                   0x90
#define MAX1_IRQ_X2                    0x91
#define MAX1_IRQ_X3                    0x92
#define MAX1_IRQ_TIMERC                0x93
#define MAX1_IRQ_MOUSE                 0x94
#define MAX1_IRQ_EXT0                  0x95
#define MAX1_IRQ_HOST                  0x96
#define MAX1_IRQ_PCCARD						0x97	
#define MAX1_IRQ_RTC_UPDATE				0x98
#define MAX1_IRQ_RTC_ALARM					0x99
#define MAX1_IRQ_RTC_PERIODIC				0x9A

// Mode for CPU-speed
#define MAX1_CPU_LOW_SPEED             0
#define MAX1_CPU_HIGH_SPEED            1
#define MAX1_CPU_HYPER_SPEED           2

// CPU speed
#define MAX1_SPEED_100MHZ              100 // only for MAX1_CPU_HYPER_SPEED
#define MAX1_SPEED_66MHZ               66  // only for MAX1_CPU_HYPER_SPEED
#define MAX1_SPEED_33MHZ               33  // only for MAX1_CPU_HIGH_SPEED
#define MAX1_SPEED_16MHZ               16  // only for MAX1_CPU_HIGH_SPEED
#define MAX1_SPEED_8MHZ                8   // for MAX1_CPU_HIGH_SPEED and _LOW_SPEED
#define MAX1_SPEED_4MHZ                4   // only for MAX1_CPU_LOW_SPEED
#define MAX1_SPEED_2MHZ                2   // only for MAX1_CPU_LOW_SPEED
#define MAX1_SPEED_1MHZ                1   // only for MAX1_CPU_LOW_SPEED

// flags for max_open_eeprom
#define MAX_CHECK_EEP_CHECKSUM			0x0001
// flags in MAX_EEPINFO_TYPE
#define MAX_EEP_AUTO_INC					0x0004

// current version of eeprom area definition
#define XBUS_EEP_REGION_HEADER_VERSION	1

// eeprom content: the following informations can be read at the given offset
// with max_read_eeprom (do not write into these eeprom words !)
#define MAX_EEPWORD_EEPTYPE            0
#define MAX_EEPWORD_EEPLENGTH          1
#define MAX_EEPWORD_EEPBUFFER          2
#define MAX_EEPWORD_INITTYPE           3
#define MAX_EEPWORD_XBUSTYPE           4
#define MAX_EEPWORD_CATEGORY           5  // values: see MAX_CATEGORY...
#define MAX_EEPWORD_MODULETYPE         6
#define MAX_EEPWORD_VARIANT            7
#define MAX_EEPWORD_REVISION           8
#define MAX_EEPWORD_PROGRAMS           14
#define MAX_EEPWORD_MANUAL             15

// eeprom content: can be accessed freely with 
// max_read_eeprom_area and max_write_eeprom_area
#define MAX_EEPAREA_USER_DATA          11
#define MAX_EEPAREA_USER	            11

// the following eeprom areas are read only areas with informations.
// Use max_read_eeprom_area. do not write into these eeprom areas !
#define MAX_EEPAREA_MODULNAME           20
#define MAX_EEPAREA_INFOTEXT            21
#define MAX_EEPAREA_MANUFACTURER        25
#define MAX_EEPAREA_PROD_DATA           27

// the following eeprom areas are reserved for system programs
// do not write into these eeprom areas !
#define MAX_EEPAREA_MDDINIT             9
#define MAX_EEPAREA_LAYERED_MDD         10
#define MAX_EEPAREA_OEM_DATA		       12
#define MAX_EEPAREA_ADR_AREA_TABLE      13
#define MAX_EEPAREA_OSINIT_PON			 16
#define MAX_EEPAREA_OSINIT_RES          17
#define MAX_EEPAREA_INITPROG            18
#define MAX_EEPAREA_MDD                 19
#define MAX_EEPAREA_MANUAL              22
#define MAX_EEPAREA_DATASHEET           23
#define MAX_EEPAREA_SUBDATA             24
#define MAX_EEPAREA_MASTER_CAP          26
#define MAX_EEPAREA_PRODUCT_INFO        27
#define MAX_EEPAREA_CHECKSUM            29
#define MAX_EEPAREA_MDD_DATA            40

#define NO_OF_MDD_EEPAREAS              10
#define NO_OF_EEPROM_PTR                (49-9)


#define  MAX_CATEGORY_CPU                       0x0002   // CPU module like X-MAX-1
#define  MAX_CATEGORY_PROCESS_IO                0x0004   // process I/O module: AIn, AOut, DIn, DOut, Counter
#define  MAX_CATEGORY_INTERFACE_PROCESS_IO      0x0008   // ???
#define  MAX_CATEGORY_COMMUNICATION             0x0010   // serial, parallel
#define  MAX_CATEGORY_HUMAN_INTERFACE           0x0020   // display, keyboard, mouse
#define  MAX_CATEGORY_MASS_STORAGE              0x0040   // HD, FD, CD, DVD...
#define  MAX_CATEGORY_INTERFACE_MASS_STORAGE    0x0080   // IDE, SCSI, EPP
#define  MAX_CATEGORY_ISOLATED                  0x8000   // galvan. isolation

// flags for usMode in function max_write_ins_file_to_flash
#define  MAX_USER_INS_FILE    1
#define  MAX_SYS_INS_FILE     2

#define  MODE_OVERWRITE_AREA  1     // mode for max_create_mddinit_eeprom_area

#endif //_INC_X_DEFS_H
