/********************************************************************
*  X_ERROR.H
*
*  This header file defines error-constants returned by the functions
*  of the SORCUS libraries for the MAX-system.
*
*  Copyrights:          SORCUS Computer GmbH 2001
*                       All Rights Reserved
********************************************************************/

#ifndef _INC_X_ERROR_H
#define _INC_X_ERROR_H





/* success - no error */
#define ERR_OK							0
#define ERR_NO_ERROR					0

/* errorclass 1: communication errors */
#define ERR_TBF_TIMEOUT					0x0101
#define ERR_RBE_TIMEOUT					0x0201
#define ERR_MACRO_PROCESSING			0x0401
#define ERR_CONNECTION_OFF			   0x0501

/* errorclass 2: initialization errors */
#define ERR_MEMORY_ALLOCATION			0x0102	// could not allocate memory (library internal)
#define ERR_BOARD_NOT_AVAILABLE		    0x0202	// board not available
#define ERR_BOARD_NOT_REACTING		    0x0302
#define ERR_WRONG_CARDTYPE				0x0402
#define ERR_MODULE_NOT_AVAILABLE		0x0502
#define ERR_MINI_OS_NOT_ACTIVE		    0x0602
#define ERR_ROM_OS_NOT_ACTIVE			0x0702
#define ERR_OSX_NOT_READ				0x0802
#define ERR_OSX_NOT_FOUND				0x0902
#define ERR_MORE_THAN_ONE_CPU			0x0A02
#define ERR_SW_RESET_NOT_POSSIBLE	    0x0B02
#define ERR_MODULE_UNKNOWN		        0x0C02

/* errorclass 3: functional errors */
#define ERR_NO_DEBUG_INFO				0x0203
#define ERR_INT_NOT_IN_USE				0x0303
#define ERR_FLASH_STATUS				0x0403
#define ERR_MDD_NOT_STARTED			    0x0D03
#define ERR_BUFFER_EMPTY				0x0F03
#define ERR_BUFFER_FULL					0x1003
//#define ERR_HARDWARE_CONFLICT         0x1103
#define ERR_PAR_SEMAPHORE_LOCKED		0x1203
#define ERR_DATA_SEMAPHORE_LOCKED	    0x1303
#define ERR_TYPE_CHECK					0x1403
#define ERR_PROG_NOT_INSTALLED		    0x1503
#define ERR_INVALID_ERROR				0x1603
#define ERR_MSG_MDD_NOT_FOUND			0x1703
#define ERR_READING_MSGMDD				0x1803
#define ERR_MDD_WITH_WRONG_VERSION	    0x1903
#define ERR_MDD_WITH_WRONG_VARIANT	    0x1A03
#define ERR_MODULE_TYPE_MISMATCH		0x1B03
#define ERR_PROG_NR_MISMATCH			0x1C03
#define ERR_EEPROM_REGION_NOT_CREATED	0x1D03
#define ERR_EEPROM_REGION_EXISTS		   0x1E03
#define ERR_SYNC_CALLBACK_NOT_POSSIBLE	0x1F03

/* errorclass 4: errors in parameter range of a task */
#define ERR_PARAMETER_RANGE				0x0004 // .. 0xFF04
// (high byte contains offset of the first invalid parameter)

/* errorclass 5: illegal value in an eeprom word */
#define ERR_EEPROM_WORD						0x0005  // .. 0xFF05
// (high byte contains number of the illegal eeprom word)

/* errorclass 7: parameter errors */
#define ERR_FILE_NOT_FOUND					0x0207
#define ERR_PROG_FORMAT						0x0307
#define ERR_LINKER_SIGNATURE				0x0407
#define ERR_READ_FILE						0x0507
#define ERR_MACRO_NOT_AVAILABLE			    0x0607
#define ERR_PROG_NOT_FOUND					0x0707
//#define ERR_MISSING_NULL_TERMINATION      0x0D07
#define ERR_ILLEGAL_COMMAND				    0x0E07
#define ERR_CALLBACK_NOT_SUPPORTED		    0x0F07
#define ERR_AXMODULE_DLL_VERSION			0x1007		 
#define ERR_AXMODULE_DLL_NOT_FOUND		    0x1107		 
#define ERR_INS_FILE_SYNTAX				    0x1207		 
#define ERR_AMLX_DLL_VERSION				    0x1307
#define ERR_AMLX_DLL_NOT_FOUND			    0x1407
#define ERR_INVALID_SYSTEM_INS 				 0x1507		 
#define ERR_TASK_ALREADY_IN_USE 				 0x1607		 
#define ERR_IRQ_ALREADY_IN_USE 				 0x1707		 
#define ERR_IRQ_MANAGER_NOT_INSTALLED	    0x1807		 
#define ERR_INTMNGR_NOT_FOUND              0x1907  
#define ERR_COULD_NOT_SET_BA               0x1A07

/* errorclass 8: driver errors */
//#define ERR_NO_DRIVER_CONNECTION		    0x0108 
//#define ERR_SRQ_UNEXPECTED				0x0208
//#define ERR_SR_MESSAGE_OVERFLOW		    0x0308
#define ERR_HOLD_REQUEST_FAILED			    0x0408
//#define ERR_NOT_ENOUGH_INSTALLATIONS	    0x0508
#define ERR_DRV_SERVICE						0x0608
#define ERR_DRIVER_NOT_OPENED				0x0708
#define ERR_CREATING_SRQ_THREAD			    0x0808
#define ERR_SRQ_THREAD_PRIORITY			    0x0908
#define ERR_DRIVER_GENERAL					0x0A08
#define ERR_PROCESSMEM_NOT_ALLOCATED	    0x0B08
#define ERR_MDD_NOT_LOADED					0x0D08
#define ERR_INSTALL_PARAMETER				0x0E08
//#define ERR_WRONG_PARAMETER_RW			0x1008
#define ERR_WRONG_PARAMETER_READ			0x1108
#define ERR_WRONG_PARAMETER_WRITE		    0x1208
#define ERR_CANNOT_WRITE_PARAMETER		    0x1308
#define ERR_WRONG_PARAMETER_TYPE			0x1408
#define ERR_PROCESS_ID_NOT_VALID			0x1508
#define ERR_LOGBUFFER_NOT_READABLE		    0x1608
#define ERR_EXCLUSIVE_LOCK_DENIED		    0x1908
#define ERR_MAX_ACCESS_DENIED				0x1A08
#define ERR_ACCESS_VIOLATION				0x1C08
#define ERR_SRP_CANCELLED					0x1D08
#define ERR_INVALID_LIST_TYPE				0x1E08
#define ERR_CORRECTION_NOT_AVAILABLE	    0x1F08

/* errorclass 9: mdd specific errors*/
#define ERR_MDD_SPECIFIC					0x0009  

// (high byte contains detailed error information)

/* errorclass D: x-bus errors */
#define ERR_XBUS_NOT_READY				0x010D
#define ERR_XBUS_SEMAPHORE_TIMEOUT		0x020D
#define ERR_XBUS_HARDWARE_RESET			0x030D
#define ERR_XBUS_ACCESS_TIMEOUT			0x040D
#define ERR_XBUS_XRES_TIMEOUT			0x050D
#define ERR_XBUS_XREQ_TIMEOUT			0x060D
#define ERR_XBUS_NO_CONFIG_MASTER		0x070D
#define ERR_TOO_MUCH_MASTERS			0x080D
#define ERR_XBUS_CFG_MASTER_FAIL		0x0A0D
#define ERR_EEP_SEMA_BUSY				0x0B0D 	
#define ERR_EEP_BYTE_ACCESS				0x0C0D
#define ERR_EEP_ACCESS					0x0D0D 
#define ERR_INVALID_VIL_CFG         0x0F0D

/* errorclass 80 .. BF : not used (reserved for srqs) */

/***********************************************************************/
// error class C0..FF: error requests
/***********************************************************************/

/* errorclass FE and FF : cpu hardware error */

/* errorclass FD : module hardware error */
#define ERR_MODULE_HARDWARE			 0x00FD
// (high byte contains slot number)

/* errorclass FC: reserved */

/* errorclass FB : system crash */
#define ERR_SYSTEM_CRASH				 0x00FB
// (high byte contains reason)

/* errorclass FA and DF : trap - not correctable / corrected */
#define ERR_TRAP_UNCORRECTED			 0x00FA
#define ERR_TRAP_CORRECTED				 0x00DF
// (high byte contains trap vector number)

/* errorclass F9 : error in prepare (main procedure) */
#define ERR_PREPARE						 0x00F9

/* errorclass F8..F4: reserved */

/* errorclass FBm F0..F3 : task crash */
#define ERR_SYSTEM_CRASH_TASK			 0x00F0
// (high byte contains task number 00..FF, second nibble is multilier with 100h)
// (e.g. 0x12F3 means task 312h has crashed) 

/* errorclass EC..EF : task crash */
#define ERR_TASK_CRASH					 0x00EC
// (high byte contains task number 00..FF, second nibble is multilier with 100h)
// (e.g. 0x12ED means task 112h has crashed) 

/* errorclass E8..EB : task not active */
#define ERR_TASK_DEACTIVATED			 0x00E8
// (high byte contains task number 00..FF, second nibble is multilier with 100h)
// (e.g. 0x12E8 means task 0012h is deactivated) 

/* errorclass E7..E4 : error in macro command */
#define ERR_TMT_TIMEOUT_IN_MACRO		 0x00E7	
#define ERR_RCV_TIMEOUT_IN_MACRO		 0x00E6	
#define ERR_ILLEGAL_MACRO				 0x00E5	
#define ERR_MACRO_CANCELLED			 0x00E4
// (high byte contains macro command code)

/* errorclass E3 : error in command */
#define ERR_IN_COMMAND					 0x00E3
// (high byte contains type of error)

/* errorclass E2 : error in host communication */
#define ERR_HOST_COMMUNICATION		 0x00E2

/* errorclass E1 : error accessing device */
#define ERR_DEVICE_ACCESS      		 0x00E1
#define ERR_NO_MODULE_ON_SLOT   		 0x80E1
// (high byte contains type of error)

/* errorclass E0 : error in function */
#define ERR_INVALID_PARAMETER			0x02E0
#define ERR_TASK_NOT_INSTALLED		0x08E0
#define ERR_NOT_IMPLEMENTED			0x09E0
#define ERR_PLAUSIBILITY				0x0BE0
#define ERR_TASK_NOT_ACTIVE	      0x0CE0
#define ERR_WRONG_FORMAT				0x0DE0
#define ERR_NOT_ENOUGH_MEMORY			0x0EE0
#define ERR_ROUTINE_NOT_IMPLEMENTED	0x0FE0
#define ERR_TIMEOUT				      0x11E0
#define ERR_READ_ONLY_DEVICE	      0x12E0
#define ERR_INVALID_HANDLE				0x14E0
#define ERR_DEVICE_NOT_AVAILABLE		0x15E0
#define ERR_WRONG_NUMBER_OF_INPUTS		0x16E0
#define ERR_WRONG_NUMBER_OF_RETURNS		0x17E0
#define ERR_FUNC_RETPARA_TOO_LARGE		0x17E0
#define ERR_FUNCTION_NOT_AVAILABLE		0x18E0
#define ERR_DEBUG_NOT_POSSIBLE			0x19E0
#define ERR_DEVICE_ALREADY_IN_USE		0x20E0
#define ERR_WRITE_IN_PROGRESS          0x22E0
#define ERR_READ_IN_PROGRESS           0x23E0
#define ERR_OSX_BUFFER_FULL		      0x24E0
#define ERR_WRONG_IRQ_NUMBER           0x31E0
#define ERR_DEVICE_NOT_READY		      0x36E0
#define ERR_NOT_CONNECTED               0x36E0
#define ERR_FLASH_WRONG_STATE           0x84E0
#define ERR_WRONG_STATE                 0x84E0
#define ERR_CLOSED		                0x84E0
#define ERR_FLASH_NOT_SUPPORTED         0x85E0
#define ERR_FLASH_WRONG_SERVICE         0x86E0
#define ERR_FLASH_NOT_AVAILABLE         0x87E0
#define ERR_FLASH_WRONG_SLOT            0x88E0
#define ERR_FLASH_ADDR_NOT_ALIGNED      0x89E0
#define ERR_FLASH_WRONG_ADDR            0x8AE0
#define ERR_FLASH_SECTOR_NOT_ERASED     0x8BE0
#define ERR_FLASH_TIMEOUT               0x8CE0
#define ERR_CPS_NOT_SUPPORTED			   0x94E0
#define ERR_INFOTEXT_NOT_AVAILABLE		0x95E0
#define ERR_SERVICE_NOT_AVAILABLE		0x96E0
#define ERR_NO_CAPTION_BUFFER			   0x97E0
#define ERR_WRONG_DATA_TYPE				0x98E0
#define ERR_RANGE_CROSS_OVER			   0x99E0
#define ERR_RANGE_CROSS_UNDER			   0x9AE0
#define ERR_INTERNAL_HARDWARE_TIMEOUT  0x9BE0
#define ERR_FUNCTION_LOCKED				0x9CE0
#define ERR_EEPROM_REGION_LENGTH		   0x9DE0
#define ERR_EEPROM_ACCESS				   0x9EE0
#define ERR_EEPROM_HEADER				   0x9FE0
#define ERR_EEPROM_REGION_HEADER		   0xA0E0
#define ERR_ARITHMETICS					   0xA1E0
#define ERR_XBUS_INVALID_CONFIG			0xA2E0
#define ERR_SETTLE_TIMER				   0xA3E0
#define ERR_SEMAPHORE_BUSY				   0xA4E0

#define ERR_COM_STATUS                  0xA7E0
#define ERR_DATA_NOT_READY              0xA8E0
#define ERR_SYSTEM_CLOCK                0xA9E0
#define ERR_DEVICE_NOT_INIT             0xA9E0
#define ERR_OVERFLOW                    0xAAE0
#define ERR_UNDERFLOW                   0xABE0
#define ERR_INVALID_DATA                0xACE0



/* errorclass DE: given parameter has illegal  value */
#define ERR_WRONG_PARAMETER			0x00DE	 // .. 0xFFDE
// (high byte contains number of the illegal parameter)

/* errorclass D0..DD : warnings */

/* errorclass CF : system wranings (sent by the driver) */
#define ERR_SRQ_BOARD_RESET		      0x00CF
#define DRVMSG_SRQBUF_WARNING		      0x01CF
#define DRVMSG_SRQBUF_ERROR		      0x02CF
#define DRVMSG_RESET_BY_SOFTWARE	      0x10CF
#define DRVMSG_RESET_BY_HARDWARE	      0x11CF
#define DRVMSG_VIL_INTERRUPT           	      0xC0CF

//SRQs used by RTDS
//29.10.2004: CB
#define SRQ_BREAKPOINT_HIT		      0x80cf
#define SRQ_CALL_FINISHED		      0x81cf


/* errorclass CE..C0 : reserved System SRQs */
#define DMA_SRQ_LOWBYTE				0xCE
#define MESSAGE_MDD_LOWBYTE		0xCB
#define SRQ_PROG_START				0xCB
#define SRQ_XBUS_CFG_READY			0xCC

#endif // _INC_X_ERROR_H
