/******************************************************************************
*  X_MDD.H
*
*  This header file contains constant and type definitions for the
*  Module-Device-Driver (MDD) functions of the SORCUS libraries
*  for the MAX-system.
*
*  Copyrights:          SORCUS Computer GmbH 2001-2004
*                       All Rights Reserved
*
******************************************************************************/

#ifndef _INC_X_MDD_H
#define _INC_X_MDD_H


// commands for max_channel_control
///////////////////////////////////
// ---------- no input / no output ----------
#define CMD_CLOSE                    0x00A0   // Close the channel
                                              // (do not use with max_channel_control)
#define CMD_SUSP_WRITE               0x00A1   // Lock data output service
#define CMD_CONT_WRITE               0x00A2   // Unlock data outpuit service
#define CMD_SUSP_READ                0x00A3   // Lock data input service
#define CMD_CONT_READ                0x00A4   // Unlock data input service
#define CMD_RESET                    0x00A5   // Reset the channel
#define CMD_START                    0x00A6   // Start the channel
#define CMD_STOP                     0x00A7   // Stop the channel
#define CMD_CONTINUE                 0x00A8   // Continue the channel
#define CMD_LATCH_OUT                0x00A9   // Transfer latch to output
#define CMD_LATCH_IN                 0x00AA   // Transfer input to latch
#define CMD_DIR_OUTPUT               0x00AB   // switch data direction to output
#define CMD_DIR_INPUT                0x00AC   // switch data direction to input
#define CMD_HIGH_SPEED_START         0x00AD   // start highspeed mode
#define CMD_HIGH_SPEED_STOP          0x00AE   // stop highspeed mode
// ---------------------------------------------------------------------------------
// module specific
// ---------------------------------------------------------------------------------
#define CMD_DIR_INPUT_RTSCTS         0x00BA   // X-SCC-2 RS-4xx RTS transmitter off
#define CMD_DIR_OUTPUT_RTSCTS        0x00BB   // X-SCC-2 RS-4xx RTS transmitter on
#define CMD_XSCC_RBUS_ON             0x00BC   // X-SCC-2 bus termination on
#define CMD_XSCC_RBUS_OFF            0x00BD   // X-SCC-2 bus termination off
#define CMD_XSCC_FAST                0x00BE   // X-SCC-2 fast mode
#define CMD_XSCC_SLOW                0x00BF   // X-SCC-2 slow mode
// ---------------------------------------------------------------------------------
#define CMD_DIR_AUTO_OUTPUT          0x00BC   // X-COM-4 
#define CMD_XCOM4_CLEAR_RCV_BUFFER   0x00BE   // X-COM-4 clear receive buffer
#define CMD_XCOM4_CLEAR_TMT_BUFFER   0x00BF   // X-COM-4 clear transmit buffer
// ---------------------------------------------------------------------------------
//#define CMD_DIR_AUTO_OUTPUT          0x00BC // X-COM-8 
#define CMD_XCOM8_CLEAR_RCV_BUFFER   0x00BE   // X-COM-8 clear receive buffer
#define CMD_XCOM8_CLEAR_TMT_BUFFER   0x00BF   // X-COM-8 clear transmit buffer
// ---------------------------------------------------------------------------------
#define CMD_XOSRAM8_CLEAR_RCV_BUFFER 0x00BE   // X-OSRAM-8 clear receive buffer
#define CMD_XOSRAM8_CLEAR_TMT_BUFFER 0x00BF   // X-OSRAM-8 clear transmit buffer
// ---------------------------------------------------------------------------------
#define CMD_XMAX400_CLEAR_RCV_BUFFER 0x00BE   // X-MAX-400 clear receive buffer
#define CMD_XMAX400_CLEAR_TMT_BUFFER 0x00BF   // X-MAX-400 clear transmit buffer
// ---------------------------------------------------------------------------------

// ---------- DWORD input ----------
#define CTRL_DEVICE                  0x0060   // Control the device
#define CTRL_RW_PTR                  0x0061   // Set the read/write pointer
#define CTRL_R_PTR                   0x0062   // Set the read pointer
#define CTRL_W_PTR                   0x0063   // Set the write pointer
#define CTRL_SET_CB_CHANNEL          0x0064   // Set Callback procedure for Message MDD
//#define CTRL_CALIB_POINT1            0x0065   // Calibration procedure, point 1
//#define CTRL_CALIB_POINT2            0x0066   // Calibration procedure, point 2
//#define CTRL_CALIB_POINT1_OUT        0x0067   // Calibration procedure, point 1
//#define CTRL_CALIB_POINT2_OUT        0x0068   // Calibration procedure, point 2
#define CTRL_CALIB_REFVAL1           0x0065
#define CTRL_CALIB_REFVAL2           0x0066
#define CTRL_CALIB_ACTVAL1           0x0067
#define CTRL_CALIB_ACTVAL2           0x0068
#define CTRL_CHANNEL	       	 	 0x0070
#define CTRL_SET_TIME                0x0071   // set time 
// module specific
#define CTRL_XDIO40_SET_GATE         0x007A
#define CTRL_XCOM4_MODEM_LINES       0x007A
#define CTRL_XCOM4_EVENT_RCV_BUFFER  0x007B
#define CTRL_XCOM4_EVENT_TMT_BUFFER  0x007C
#define CTRL_XCOM8_MODEM_LINES       0x007A
#define CTRL_XCOM8_EVENT_RCV_BUFFER  0x007B
#define CTRL_XCOM8_EVENT_TMT_BUFFER  0x007C
#define CTRL_XOSRAM8_MODEM_LINES     0x007A
#define CTRL_XC163_SET_PULSE_PAUSE_RATIO       0x007A
#define CTRL_XC163_SET_MULTIPLE      0x007B
#define CTRL_XDPS_SET_IDENT_NO       0x007A
#define CTRL_XSCC_SET_CONFIG         0x007A  // for test only
#define CTRL_XMAX400_MODEM_LINES     0x007A
#define CTRL_XMAX400_EVENT_RCV_BUFFER 0x007B
#define CTRL_XMAX400_EVENT_TMT_BUFFER 0x007C

// ---------- BLOCK input ----------
#define CTRL_CAPTION                 0x0090   // Set caption of channel
#define CTRL_SET_CB_DATA			 0x0091   // Set Callback data for Message MDD
#define CTRL_CHANGE_RANGE			 0x0092   // change I/O range of I/Os
#define CTRL_CALIB_INFO              0x0093
#define CTRL_CALIB_PARAMETER         0x0094
#define CTRL_LINEARIZATION_TABLE     0x0095
// module specific
#define CTRL_XC163_SET_PERIOD        0x009A
#define CTRL_XDA16_SET_RESET_VAL     0x009A
#define CTRL_XMAX400_SET_COMMAND     0x009D

// Info types for max_channel_info
//////////////////////////////////
// ---------- DWORD output (0x4*; 0x5*) ----------
#define INFO_STATUS         0x0040   // Status of channel
// free                     0x0041   
#define INFO_DATA_TYPE      0x0042   // Data type to transfer
#define INFO_TRANSFER_MODE  0x0043   // Supported transfer mode
#define INFO_MINSIZE        0x0044   // Minimum data length
#define INFO_MAXSIZE        0x0045   // Maximum data langth
#define INFO_RANGE          0x0046   // Range
#define INFO_RESOLUTION     0x0047   // Resolution
#define INFO_DEVICE         0x0048   // Device information
#define INFO_BASE_DATA_TYPE 0x0049  // base data typ for block mode channels
#define INFO_ERROR          0x004A   // Get Error Info
// free                     0x004B
// free                     0x004C
// free                     0x004D
// free                     0x004E
// free                     0x004F
#define INFO_RW_PTR         0x0050   // Position read/write pointer
#define INFO_R_PTR          0x0051   // Position read pointer
#define INFO_W_PTR          0x0052   // Position write pointer
#define INFO_CAPTION_SIZE   0x0053   // Read size of channel caption
#define INFO_CPS_SIZE       0x0054   // Read size of channel cps
#define INFO_CDT_SIZE       0x0055   // Read size of channel cdt
#define INFO_PAR_SIZE       0x0056   // Read size of channel parameters
#define INFO_DATA           0x0057   // Get data info
#define INFO_SYNC_CALLBACK  0x0058   // For callback channels
#define INFO_STATE			0x0059   // mdd state
// module specific          0x005A 
// module specific          0x005B 
// module specific          0x005C 
// module specific          0x005D 
// module specific          0x005E 
// module specific          0x005F 
#define	STATE_STARTED		0x0000
#define	STATE_ACTIVE		0x0001
#define	STATE_STOPPED		0x0002

// module specific 0x5A ... 0x5F
#define INFO_XCOM4_RCV_BUFFER  0x005C   
#define INFO_XCOM4_TMT_BUFFER  0x005D
#define INFO_XCOM4_MODEM_LINES 0x005E
#define INFO_XCOM4_BAUDRATE    0x005F

#define INFO_XCOM8_RCV_BUFFER  0x005C   
#define INFO_XCOM8_TMT_BUFFER  0x005D
#define INFO_XCOM8_MODEM_LINES 0x005E
#define INFO_XCOM8_BAUDRATE    0x005F

#define INFO_XMAX400_RCV_BUFFER  0x005C
#define INFO_XMAX400_TMT_BUFFER  0x005D
#define INFO_XMAX400_MODEM_LINES 0x005E
#define INFO_XMAX400_BAUDRATE    0x005F

#define INFO_XOSRAM8_BAUDRATE  0x005F

#define INFO_XCAN_CAN_ID       0x005C   
#define INFO_XCAN_MSG_COUNT    0x005D

#define INFO_XDPS_ID           0x005C   
#define INFO_XDPS_CFG          0x005D
#define INFO_XSCC_GET_CONFIG   0x005C    // for test only

#define INFO_XMAX400_TIMER_FREQ   0x005C    

// ---------- BLOCK output (0x8*) ----------
#define INFO_CAPTION            0x0080   // Read caption of channel
#define INFO_CPS                0x0081   // Read CPS of the channel
#define INFO_CDT                0x0082   // Read CDT of the channel
#define INFO_PAR                0x0083   // Read CDT parameter of the channel
#define INFO_SERVICE_LIST       0x0084   // Read service list of a channel
#define INFO_CALIB_PARAMETER    0x0085
#define INFO_RANGE_EX           0x0086   // Range (one value for each IO included)
#define INFO_CALIB_DATA         0x0087   // Read calibration data
#define INFO_LINEARIZATION_TABLE 0x0088  // read linearization table
// module specific
#define INFO_DEVOBJINFO		    0x0086	  // Read internal infos (for internal use only X-CAN-2)

// Data type identifiers
// result of max_channel_info (INFO_DATA_TYPE)
#define DATA_VOID          0x00000001UL   // No transfer data
#define DATA_BIT           0x00000002UL   // 1 bit
#define DATA_UCHAR         0x00000003UL   // Unsigned 8 bit
#define DATA_CHAR          0x00000004UL   // Signed 8 bit
#define DATA_USHORT        0x00000005UL   // Unsigned 16 bit
#define DATA_SHORT         0x00000006UL   // Signed 16 bit
#define DATA_ULONG         0x00000007UL   // Unsigned 32 bit
#define DATA_LONG          0x00000008UL   // Signed 32 bit
#define DATA_BLOCK         0x00000009UL   // Block (n bytes)
#define DATA_STREAM        0x0000000AUL   // Stream
#define DATA_NORMALIZED_V  0x0000000BUL   // Normalized signed 32 bit format: UNIT = 1 uV
#define DATA_NORMALIZED_A  0x0000000CUL   // Normalized signed 32 bit format: UNIT = 1 nA

#define ADD_ID_MDD_OUTPUT_SERVICE         0x0020
#define ADD_ID_MDD_INPUT_SERVICE          0x0030

// Flags for data transfer modes
// result of max_channel_info (INFO_TRANSFER_MODE)
#define R_MODE          0x00000001UL   // Read only
#define W_MODE          0x00000002UL   // Write only
#define RW_MODE         0x00000003UL   // Read and write
#define CALLBACK_MODE   0x00000004UL   // support for message mdd

// Flags for channel status
// result of max_channel_info (INFO_SATUS)
#define _CSR_EXCLUSIVE     0x00000001UL   // Exclusive used
#define _CSR_HW_FORMAT     0x00000002UL   // Data in hardware format
#define _CSR_UNCORRECTED   0x00000004UL   // Uncorrected data
#define _CSR_OUT_SUSP      0x00010000UL   // Output suspended
#define _CSR_CONV_BLOCK    0x00004000UL   // values are converted to block mode
#define _CSR_IN_SUSP       0x00020000UL   // Input suspended
#define _CSR_OUT_LANGUAGE_C  0x00040000UL // output service is written in C
#define _CSR_IN_LANGUAGE_C   0x00080000UL // output service is written in C

// Device types used in the CPS
// result of max_channel_info (INFO_DEVICE)
#define DEVICE_TEST		           0x0000   // for internal test purpose
#define DEVICE_INFO		           0x0001   // for internal info purpose
#define DEVICE_DIN		           0x0101   // Digital input
#define DEVICE_DOUT			       0x0102   // Digital output
#define DEVICE_DIO			       0x0103   // Digital input/output
#define DEVICE_AIN_SE		       0x0201   // Analog input, single-ended
#define DEVICE_AIN_DIFF		       0x0202   // Analog input, difference
#define DEVICE_AOUT			       0x0203   // Analog output
#define DEVICE_TRIG                0x0301   // Trigger device
#define DEVICE_TRIGGER             0x0301   // Trigger device
#define DEVICE_CTRL                0x0401   // Control device
#define DEVICE_LED                 0x0402   // LED
#define DEVICE_TIMER               0x0501   // Timer
#define DEVICE_WATCHDOG            0x0503   // Watchdog
#define DEVICE_COUNTER             0x0601   // Counter
#define DEVICE_UP_COUNTER          0x0602   // Up-Counter
#define DEVICE_DOWN_COUNTER        0x0603   // Down-Counter
#define DEVICE_UP_DOWN_COUNTER     0x0604   // Up-Down-Counter
#define DEVICE_FREQUENCY_COUNTER   0x0605	// Frequeny-Counter
#define DEVICE_PULSEWIDTH_COUNTER  0x0606	// Pulsewidth-Counter
#define DEVICE_PERIOD_COUNTER      0x0607   // Period-Counter
#define DEVICE_VELOCITY_COUNTER    0x0608   // Velocity-Counter
#define DEVICE_INCREMENTAL_COUNTER 0x0609   // Incremental-Counter
#define DEVICE_PWM                 0x060A   // Pulse-Width Modulation
#define DEVICE_CLOCK               0x0701   // Clock
#define DEVICE_CALENDAR            0x0702   // Calendar
#define DEVICE_SCC                 0x0801   // Serial com. device
#define DEVICE_COM                 0x0802   // Serial COM device
#define DEVICE_SQRWAVE             0x0901   // Square wave output
#define DEVICE_EEPROM              0x0A01   // Eeprom
#define DEVICE_REGISTER            0x0A02   // Hardware register
#define DEVICE_HW_INT              0x0B01   // Hardware interrupt
#define DEVICE_SSI                 0x0C01   // SSI device
#define DEVICE_BUS_IN              0x0D01   // Bus device to transmit data
#define DEVICE_BUS_OUT             0x0D02   // Bus device to receive data
#define DEVICE_SRQ_RCV             0x0D03	  // message mdd
#define DEVICE_SRQ_TMT             0x0D04	  // message mdd
#define DEVICE_DIAGNOSIS           0x0D05   // device for diagnostics	
#define DEVICE_TCP_SOCKET          0x0D06   // TCP socket 
#define DEVICE_SSP                 0x0D07   // synchron serial port 
#define DEVICE_TEMPERATURE         0x0D08   // temperature measurement 

// Physical I/O ranges
// result of max_channel_info (INFO_RANGE)
#define RANGE_VOID         0x0001   // No range
#define RANGE_UPP_312MV5   0x0021   // + 312.5 mV
#define RANGE_UPP_625MV    0x0022   // + 625 mV
#define RANGE_UPP_1V25     0x0023   // + 1.25 V
#define RANGE_UPP_2V5      0x0024   // + 2.5 V
#define RANGE_UPP_5V       0x0025   // + 5 V
#define RANGE_UPP_10V      0x0026   // + 10 V
#define RANGE_UPP_2V       0x0027   // + 2 V
#define RANGE_UPP_1V       0x0028   // + 1 V
#define RANGE_UPP_500MV    0x0029   // + 500 mV
#define RANGE_UPP_250MV    0x002A   // + 250 mV
#define RANGE_UPP_4V       0x002B   // + 4 V
#define RANGE_UPP_40MV     0x002C   // + 40 mV
#define RANGE_UPN_312MV5   0x0041   // - 312.5 mV
#define RANGE_UPN_625MV    0x0042   // - 625 mV
#define RANGE_UPN_1V25     0x0043   // - 1.25 V
#define RANGE_UPN_2V5      0x0044   // - 2.5 V
#define RANGE_UPN_5V       0x0045   // - 5 V
#define RANGE_UPN_10V      0x0046   // - 10 V
#define RANGE_BIP_312MV5   0x0061   // +/- 312.5 mV
#define RANGE_BIP_625MV    0x0062   // +/- 625 mV
#define RANGE_BIP_1V25     0x0063   // +/- 1.25 V
#define RANGE_BIP_2V5      0x0064   // +/- 2.5 V
#define RANGE_BIP_5V       0x0065   // +/- 5 V
#define RANGE_BIP_10V      0x0066   // +/- 10 V
#define RANGE_BIP_2V       0x0067   // +/- 2 V
#define RANGE_BIP_1V       0x0068   // +/- 1 V
#define RANGE_BIP_500MV    0x0069   // +/- 500 mV
#define RANGE_BIP_250MV    0x006A   // +/- 250 mV
#define RANGE_BIP_100MV    0x006B   // +/- 100 mV
#define RANGE_20MA         0x0081   // 0..20 mA
#define RANGE_BIP_20MA     0x0082   // +/- 20 mA
#define RANGE_N20MA        0x0083   // 0..-20 mA
#define RANGE_USER_A_UP    0x0091   // user defined range
#define RANGE_USER_B_UP    0x0092   // user defined range
#define RANGE_USER_C_UP    0x0093   // user defined range
#define RANGE_USER_D_UP    0x0094   // user defined range
#define RANGE_USER_A_BIP   0x00A1   // user defined range
#define RANGE_USER_B_BIP   0x00A2   // user defined range
#define RANGE_USER_C_BIP   0x00A3   // user defined range
#define RANGE_USER_D_BIP   0x00A4   // user defined range
#define RANGE_USER         0x00A5   // user defined range

// Flags in CPS
// Flags for all MDDs
#define _CP_NO_FLAGS       0x0000   // No flags
#define _CP_EXCLUSIVE      0x0001   // Use channel exclusive
#define _CP_HW_FORMAT      0x0002   // Use hardware format
#define _CP_UNCORRECTED    0x0004   // No use of correction
#define _CP_FORCE_BLOCK    0x4000   // create block mode channel
#define _CP_SYNC_CALLBACK  0x8000	// call user callback synchronously via message mdd

// MDD specific: 0008h...0100h
#define _XDPS_SET_ADDR_SUPPORT	0x0008   // X-DPS specific
//#define _CP_AUTORUN            0x0008   // Autorun mode (XC163) // JS 22.11.02
#define _CP_HIGH_SPEED           0x0010   // High speed mode
#define _XC163_NEW_DATA_ONLY     0x0020   // X-C16-3 specific
#define XCAN_29BIT_ID            0x0008   // X-CAN specific
#define XCAN_NO_INT              0x0010   // X-CAN specific
#define XCAN_EXCL_BUFFER         0x0020   // X-CAN specific
#define XCAN_REMOTE              0x0040   // X-CAN specific
#define XCAN_NEW_ONLY            0x0080   // X-CAN specific
#define XDA16I4F_REPEAT_ON_ERROR 0x0010   // X-DA16i-4/F specific
#define XSCC_DTR_INTERNAL        0x0010   // X-SCC-2 specific
#define XSCC_RTS_FROM_TRXC       0x0020   // X-SCC-2 specific

// Read/Write modes in CPS
#define IO_MODE_DIRECT     0x0001   // Direct I/O
#define IO_MODE_LATCH      0x0002   // Latched I/O
#define IO_MODE_RAM        0x0004   // I/O to/from RAM
#define IO_MODE_RAM_LATCH  0x0006   // I/O to/from RAM/Latch
#define IO_MODE_MULTIPLE   0x0008   // read multiple data


/////////////////////////////////////////////////
// Flags for serial interfaces
/////////////////////////////////////////////////
// Type of COM interface
#define COM_RS232                   0x0001
#define COM_RS422                   0x0002
#define COM_RS485                   0x0004
#define COM_RS485_HALF_DUPLEX       0x0004
#define COM_RS485_FULL_DUPLEX       0x0005
#define COM_CURRENT_LOOP            0x0006
#define COM_TTL                     0x0007

// Flow control for serial interfaces
#define COM_NO_FLOW        0x0001
#define COM_XONXOFF_FLOW   0x0002
#define COM_RTSCTS_FLOW    0x0004

// stop bits
#define COM_ONE_STOPBIT    0x0001
#define COM_ONE5_STOPBITS  0x0002
#define COM_TWO_STOPBITS   0x0004

// parity
#define COM_NO_PARITY      0x0001
#define COM_EVEN_PARITY    0x0002
#define COM_ODD_PARITY     0x0004
#define COM_SPACE_PARITY   0x0008
#define COM_MARK_PARITY    0x0010

// byte size
#define COM_5_BITS         0x0001
#define COM_6_BITS         0x0002
#define COM_7_BITS         0x0004
#define COM_8_BITS         0x0008

#define _COM_REPLACE_ERR_CHAR  0x0002


// all structs are word aligned
#ifndef __BORLANDC__
   #ifdef PLATFORM_LINUX
	    #ifndef HANDLE_SYSV_PRAGMA
	          #define HANDLE_SYSV_PRAGMA 1
	    #endif
      #pragma pack(1)
   #else
      #pragma pack(push, SORCPACK, 1)
   #endif
#else
   #ifndef _RTLIB_
      #pragma option -a1
   #endif
#endif

// CPS definitions
//////////////////

// X-AD14-20
typedef struct _CPS_XAD1420
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usRange;
   USHORT   usSettleTime;
}
CPS_XAD1420, *PCPS_XAD1420;

// new definition for MDD 1.J.004
typedef struct _CPS_XAD1420_A
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usRange;
   USHORT   usSettleTime;
   USHORT	usHWOversampling;
   USHORT	usSWOversampling;
}
CPS_XAD1420_A, *PCPS_XAD1420_A;


// X-DA16-4
typedef struct _CPS_XDA164
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usRange;
}
CPS_XDA164, *PCPS_XDA164;

// X-DA16i-4/F
typedef struct _CPS_XDA16I4F
{
   USHORT   usVersion;
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usRange;
   USHORT   usThreshold;
   ULONG    usMode;
   ULONG    usSubMode;
   ULONG    ulDataNo;
   ULONG    ulFrequency;
}
CPS_XDA16I4F, *PCPS_XDA16I4F;

// X-DA16i-4/F
typedef struct 
{
   USHORT    usSlot;
   USHORT    usLayer;
} 
XDA16I4_MODULE_LOCATION;

// X-DA16i-4/F and X-DA16i-4
typedef struct 
{
   USHORT    usControl;
   USHORT    usData;
   LONG      lData;
} 
XDA164_CONTROL_TYPE;

// defines for CPS values for X-DA16i-4/F
#define XDA16I4_MODE_0                  0
#define XDA16I4_FIFO_MODE_1             1
#define XDA16I4_BUFFER_CONTROL          4
// callback events for X-DA16i-4/F
#define XDA16I4_EVENT_BUFFER_UNDERFLOW  1
#define XDA16I4_EVENT_READY_FOR_DATA    2
#define XDA16I4_EVENT_BUFFER_OVERRUN    3
// commands for control channel for X-DA16i-4/F
#define XDA16I4_START_SOFTWARE          1
#define XDA16I4_START_TRIGGER           2

// commands for control channel for X-DA16i-4/F and X-DA16i-4
#define XDA164_USE_RESET_VALUE            1
#define XDA164_ALL_ZERO                   2
#define XDA164_KEEP_LAST_VALUE            3
#define XDA164_CHANGE_RANGE               4

//trigger modes
#define TRIGGER_POS_EDGE	0x0001
#define TRIGGER_NEG_EDGE	0x0002
#define TRIGGER_HIGH_LEVEL  0x0004
#define TRIGGER_LOW_LEVEL   0x0008
#define TRIGGER_SOFTWARE    0x0010  

// X-AD16-4
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usRange;
   USHORT	usOversampling;
}
CPS_XAD164, *PCPS_XAD164;

#define XAD164_RANGE_SETTING 	1

// X-DIO-40
typedef struct _CPS_XDIO40
{
    USHORT        usDevice;
    USHORT        usIndexFirst;
    USHORT        usIndexLast;
    USHORT        usFlags;
    USHORT        usMode;
    USHORT        usReadMode;
    USHORT        usWriteMode;
}
CPS_XDIO40, *PCPS_XDIO40;
typedef struct
{
    USHORT ausPosEdge[3];
    USHORT ausNegEdge[3];
}
XDIO40_CALLBACK_EVENTS;
typedef struct
{
    USHORT ausPending[3];
    USHORT ausOverrun[3];
}
XDIO40_INTERRUPT;
typedef struct _CPS_XDIO40_A
{
    USHORT                  usDevice;
    USHORT                  usIndexFirst;
    USHORT                  usIndexLast;
    USHORT                  usFlags;
    USHORT                  usMode;
    USHORT                  usReadMode;
    USHORT                  usWriteMode;
    ULONG                   ulTimeout;
    ULONG                   ulCallbackEvents;
    XDIO40_CALLBACK_EVENTS  rcCallbackEvents;
}
CPS_XDIO40_A, *PCPS_XDIO40_A;

// mode
#define _XDIO40_TIMER_MODE_0            0x0000
#define _XDIO40_TIMER_MODE_1            0x0001
#define _XDIO40_TIMER_MODE_2            0x0002
#define _XDIO40_TIMER_MODE_3            0x0003
#define _XDIO40_TIMER_MODE_4            0x0004
#define _XDIO40_TIMER_MODE_5            0x0005
#define _XDIO40_TIMER_MODE_BCD          0x0010
#define _XDIO40_TIMER_MODE_BINARY       0x0020
#define XDIO40_READ_ONLY                0x0040
// flags
#define _XDIO40_CLOCK_DIO               0x0002
#define _XDIO40_CLOCK_1MHZ              0x0004
#define _XDIO40_GATE_SOFTWARE           0x0008
#define _XDIO40_GATE_T2OUT              0x0010
#define _XDIO40_GATE_DIO                0x0020
#define _XDIO40_OUT_DIO                 0x0040
#define _XDIO40_OUT_NO                  0x0080
// callbackevents
#define XDIO40_EVENT_POS_EDGE           0x1
#define XDIO40_EVENT_NEG_EDGE           0x2
#define XDIO40_EVENT_WATCHDOG           0x4
// callback data
#define XDIO40_INTERRUPT_PENDING        0x1
#define XDIO40_INTERRUPT_OVERRUN        0x2

// X-OPT-io
typedef struct _CPS_XOPTIO
{
    USHORT usDevice;
    USHORT usIndexFirst;
    USHORT usIndexLast;
    USHORT usFlags;
    USHORT usReadMode;
    USHORT usWriteMode;
}
CPS_XOPTIO, *PCPS_XOPTIO;

typedef struct _CPS_XOPTIO_A
{
    USHORT usDevice;
    USHORT usIndexFirst;
    USHORT usIndexLast;
    USHORT usFlags;
    USHORT usReadMode;
    USHORT usWriteMode;
    ULONG  ulCallbackEvents;
    ULONG  ulTimeout;
}
CPS_XOPTIO_A, *PCPS_XOPTIO_A;
#define XOPTIO_EVENT_NEG_EDGE   0x1
#define XOPTIO_EVENT_POS_EDGE   0x2
#define XOPTIO_EVENT_WATCHDOG   0x4
#define XOPTIO_INPUT_FILTER     0x2
#define XOPTIO_33MHZ            33000000
#define XOPTIO_SYSTEM_CLOCK     0x1


// DIP_LED
#define	LED_RED		0x0001
#define LED_GREEN	0x0002
#define	LED_BLUE	0x0004
typedef struct _CPS_DIP_LED
{
        USHORT        usDevice;
        USHORT        usIndexFirst;
        USHORT        usIndexLast;
        USHORT        usFlags;
        USHORT        usReadMode;
        USHORT        usWriteMode;
}
CPS_DIP_LED, *PCPS_DIP_LED;

// X-REL-8
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usTimeout;
}
CPS_XREL8, *PCPS_XREL8;

// X-DAD-4
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usRange;
}
CPS_XDAD4, *PCPS_XDAD4;

//X-5B-1
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usRange;
   USHORT   usSettleTime;
   USHORT	usOversampling;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
}
CPS_X5B1, *PCPS_X5B1;

// X-MIX-26
typedef struct
{
   USHORT   usVersion;
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usRange;
   USHORT   usTimeout;
   USHORT   usTrigger;
   ULONG    ulPosCallback;
   ULONG    ulNegCallback;   
}
CPS_XMIX26, *PCPS_XMIX26;

#define	XMIX26_LOW_POWER					1
#define	XMIX26_HIGH_SPEED					2

#define	XMIX26_TRIG_AIN					   0x0001
#define	XMIX26_TRIG_DIN_0_15		         0x0002
#define	XMIX26_TRIG_DIN_16_18		      0x0004
#define	XMIX26_TRIG_AOUT					   0x0008
#define	XMIX26_TRIG_DOUT_0_15			   0x0010
#define	XMIX26_TRIG_DOUT_16_18			   0x0020


// X-C16-3
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usMode;
   USHORT	usReferenceTime;
   USHORT	usMultiple;
   USHORT	usCounterInput;
   ULONG	   ulControlInput;
}
CPS_XC163, *PCPS_XC163;

// new definition for MDD 1.H.001
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usMode;
   USHORT	usReferenceTime;
   USHORT	usMultiple;
   USHORT	usCounterInput;
   ULONG	   ulControlInput;
   ULONG    ulCallbackEvent;  // new in version 1.H.001
}
CPS_XC163_A, *PCPS_XC163_A;

typedef struct
{
    USHORT usSec;
    USHORT usMSec;
    USHORT usUSec;
    USHORT usNSec;
}
XC163_TIME;

#define XC163_EVENT_POS_EDGE            0x00000001
#define XC163_EVENT_NEG_EDGE            0x00000002
#define XC163_EVENT_OVERFLOW            0x00000004
#define XC163_EVENT_OVERFLOW_UP         0x00000004
#define XC163_EVENT_UNDERFLOW           0x00000008
#define XC163_EVENT_OVERFLOW_DOWN       0x00000008
#define XC163_EVENT_END_OF_MEASUREMENT  0x00000010
#define XC163_EVENT_START               0x00000020
#define XC163_EVENT_STOP                0x00000040
#define XC163_EVENT_LOAD                0x00000080
#define XC163_EVENT_LATCH               0x00000100
#define XC163_EVENT_RESET               0x00000200

#define	XC163_DIN_LATCH_CTRL			0x0001
#define	XC163_DIN_TRIGGER				0x0002
#define	XC163_COUNTER_HW_CTRL			0x0004
#define	XC163_COUNTER_SW_CTRL			0x0008
#define XC163_INPUT_FILTER              0x0010

#define	_XC163_DIN_0					0x0
#define	_XC163_DIN_1					0x1
#define	_XC163_DIN_2					0x2
#define	_XC163_DIN_3					0x3
#define	_XC163_DIN_4					0x4
#define	_XC163_DIN_5					0x5
#define	_XC163_DIN_6					0x6
#define	_XC163_DIN_7					0x7
#define	_XC163_DIN_8					0x8
#define	_XC163_DIN_9					0x9
#define	_XC163_DIN_10					0xa
#define	_XC163_DIN_11					0xb
#define	_XC163_POS_EDGE					0x8000
#define	_XC163_NEG_EDGE					0x4000
#define	_XC163_ENABLE					0x2000
#define	_XC163_DISABLE					0x1000

#define	_XC163_DIN_0_1					0x1
#define	_XC163_DIN_2_3					0x2
#define	_XC163_DIN_4_5					0x4
#define	_XC163_DIN_6_7					0x8
#define	_XC163_DIN_8_9					0x10
#define	_XC163_DIN_10_11				0x20
#define	_XC163_NEG_EDGE_A				0x40
#define	_XC163_NEG_EDGE_B				0x80

#define _XC163_MODE_A					0x1
#define _XC163_MODE_B					0x2
#define	_XC163_CONTINUOUS				0x4
#define	_XC163_AUTORUN					0x8
//#define	_XC163_AUTOFREEZE				0x10
#define	_XC163_AUTORESET				0x20
#define	_XC163_AUTOLOAD_UNDERFLOW		0x40
#define	_XC163_SINGLE_A					0x80
#define	_XC163_SINGLE_B					0x100
#define	_XC163_DOUBLE_A					0x200
#define	_XC163_DOUBLE_B					0x400
#define	_XC163_QUADRUPLE				0x800
#define	_XC163_MULTIPLE					0x1000
#define _XC163_OVERRIDE					0x2000
#define	_XC163_OUTPUT					0x4000

#define	XC163_EXTERNAL	0
#define	XC163_20MHZ		1
#define	XC163_10MHZ		2
#define	XC163_5MHZ		3
#define	XC163_2MHZ		4
#define	XC163_1MHZ		5
#define	XC163_500KHZ	6
#define	XC163_200KHZ	7
#define	XC163_100KHZ	8
#define	XC163_50KHZ		9
#define	XC163_20KHZ		10
#define	XC163_10KHZ		11
#define	XC163_5KHZ		12
#define	XC163_2KHZ		13
#define	XC163_1KHZ		14
#define	XC163_500HZ		15
#define	XC163_200HZ		16
#define	XC163_100HZ		17
#define	XC163_50HZ		18
#define	XC163_20HZ		19
#define	XC163_10HZ		20

#define	XC163_50NS		1
#define	XC163_100NS		2
#define	XC163_200NS		3
#define	XC163_500NS		4
#define	XC163_1US		5
#define	XC163_2US		6
#define	XC163_5US		7
#define	XC163_10US		8
#define	XC163_20US		9
#define	XC163_50US		10
#define	XC163_100US		11
#define	XC163_200US		12
#define	XC163_500US		13
#define	XC163_1MS		14
#define	XC163_2MS		15
#define	XC163_5MS		16
#define	XC163_10MS		17
#define	XC163_20MS		18
#define	XC163_50MS		19
#define	XC163_100MS		20

#define _XC163_DIN_0_1_TO_CTRL_0_1		0x1
#define _XC163_DIN_2_3_TO_CTRL_0_1		0x2
#define _XC163_DIN_6_7_TO_CTRL_0_1		0x4
#define _XC163_DIN_8_9_TO_CTRL_0_1		0x8
#define _XC163_DIN_0_1_TO_CTRL_2_3		0x10
#define _XC163_DIN_4_5_TO_CTRL_2_3		0x20
#define _XC163_DIN_6_7_TO_CTRL_2_3		0x40
#define _XC163_DIN_10_11_TO_CTRL_2_3	0x80
#define	_XC163_CTRL_0_NEG_EDGE			0x100
#define	_XC163_CTRL_1_NEG_EDGE			0x200
#define	_XC163_CTRL_2_NEG_EDGE			0x400
#define	_XC163_CTRL_3_NEG_EDGE			0x800

#define	_XC163_COUNTER_0		0x1
#define	_XC163_COUNTER_1		0x2
#define	_XC163_COUNTER_2		0x4

#define	_XC163_START_COUNTER	0x10
#define	_XC163_STOP_COUNTER		0x20
#define	_XC163_LOAD_COUNTER		0x40
#define	_XC163_LATCH_COUNTER	0x80
#define	_XC163_RESET_COUNTER	0x100

#define	_XC163_START_CTRL_0		0x1
#define	_XC163_START_CTRL_1		0x2
#define	_XC163_START_CTRL_2		0x4
#define	_XC163_START_CTRL_3		0x8
#define	_XC163_STOP_CTRL_0		0x10
#define	_XC163_STOP_CTRL_1		0x20
#define	_XC163_STOP_CTRL_2		0x40
#define	_XC163_STOP_CTRL_3		0x80
#define	_XC163_LOAD_CTRL_0		0x100
#define	_XC163_LOAD_CTRL_1		0x200
#define	_XC163_LOAD_CTRL_2		0x400
#define	_XC163_LOAD_CTRL_3		0x800
#define	_XC163_LATCH_CTRL_0		0x1000
#define	_XC163_LATCH_CTRL_1		0x2000
#define	_XC163_LATCH_CTRL_2		0x4000
#define	_XC163_LATCH_CTRL_3		0x8000
#define	_XC163_RESET_CTRL_0		0x10000
#define	_XC163_RESET_CTRL_1		0x20000
#define	_XC163_RESET_CTRL_2		0x40000
#define	_XC163_RESET_CTRL_3		0x80000

#define _XC163_NEW_DATA			0x1

// X-TEST-1
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usRange;
   ULONG		ulChannel;
   USHORT	usOversampling;
}
CPS_XTEST1, *PCPS_XTEST1;

#define	XTEST1_AIN_AGND_AGND		1
#define	XTEST1_AIN_IP3_AGND			2
#define	XTEST1_AIN_IP12_AGND		3
#define	XTEST1_AIN_IM12_AGND		4
#define	XTEST1_AIN_AGND_P3			5
#define	XTEST1_AIN_AGND_P5			6
#define	XTEST1_AIN_DAC1A_AGND		7
#define	XTEST1_AIN_DAC2A_AGND		8
#define	XTEST1_AIN_DAC1A_DAC1B		9
#define	XTEST1_AIN_DAC2A_DAC2B		10
#define	XTEST1_AIN_INA1_INB1		11
#define	XTEST1_AIN_INA1_AGND		12
#define	XTEST1_AIN_INA2_INB2		13
#define	XTEST1_AIN_INA2_AGND		14

#define	_XTEST1_AUTO					0x1

#define XTEST1_CTRL_EEPROM_DATA     0x1

// X-SSi-2
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usMode;
   USHORT   usDataMode;
   ULONG    ulClock;
   USHORT   usBit;
}
CPS_XSSI2, *PCPS_XSSI2;


typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usMode;
   USHORT   usDataMode;
   ULONG    ulClock;
   USHORT   usBit;
   USHORT   usVersion;
}
CPS_XSSI2_A, *PCPS_XSSI2_A;

#define XSSI2_SYSTEM_CLOCK       0x1
#define XSSI2_GRAY_TO_BINARY		0x1
#define _XSSI2_MANUAL_MODE       0x20
#define XSSI2_33MHZ              33000000
#define XSSI2_AUTO_MODE         0x10
#define XSSI2_MANUAL_MODE       0x20
#define XSSI2_CONTINUOUS_MODE   0x40

// X-SSI-i
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   ULONG    ulFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   ULONG    ulMode;
   USHORT   usDataMode;
   ULONG    ulClock;
   USHORT   usBit;
   ULONG    ulInterruptEvent;
}
CPS_XSSII, *PCPS_XSSII;

#define XSSII_GRAY_TO_BINARY	 0x1
#define XSSII_MANUAL_MODE       0x20


// X-AD24-4i
typedef struct
{
   USHORT   usVersion;
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   ULONG    ulFlags;
   ULONG    ulMode;
   ULONG    ulFilter;
   ULONG    ulSensor;
   ULONG    ulTrigger;
   ULONG    ulCallbackEvents;
   USHORT   usOversampling;
}
CPS_XAD244I, *PCPS_XAD244I;

#define XAD244I_MODE_TRIGGER        0x0001
#define XAD244I_MODE_CONTINUOUS     0x0002
#define XAD244I_MODE_ACTUAL_VALUE   0x0004
#define XAD244I_MODE_NEW_VALUE      0x0008

#define XAD244I_NO_FILTER               0x00000000
#define XAD244I_50_HZ_FILTER            0x00320000
#define XAD244I_60_HZ_FILTER            0x003C0000

#define _XAD244I_EVENT_NEW_DATA         0x0001

#define _XAD244I_DIN_POS_EDGE           0x0001
#define _XAD244I_DIN_NEG_EDGE           0x0002

#define XAD244I_SENSOR_UNDEFINED        0x0000
#define XAD244I_SENSOR_USER_01          0x0001
#define XAD244I_SENSOR_USER_02          0x0002
#define XAD244I_SENSOR_USER_03          0x0003
#define XAD244I_SENSOR_USER_04          0x0004
#define XAD244I_SENSOR_THERMOCOUPLE_J   0x0005
#define XAD244I_SENSOR_THERMOCOUPLE_K   0x0006
#define XAD244I_SENSOR_THERMOCOUPLE_T   0x0007
#define XAD244I_SENSOR_THERMOCOUPLE_E   0x0008
#define XAD244I_SENSOR_THERMOCOUPLE_R   0x0009
#define XAD244I_SENSOR_THERMOCOUPLE_S   0x000A
#define XAD244I_SENSOR_THERMOCOUPLE_B   0x000B
#define XAD244I_SENSOR_THERMOCOUPLE_C   0x000C
#define XAD244I_SENSOR_THERMOCOUPLE_N   0x000D
#define XAD244I_SENSOR_PT100            0x000E
#define XAD244I_SENSOR_PT1000           0x000F

typedef struct _XAD244I_LIN_TABLE
{
    USHORT  usVersion;
    USHORT  usSize;
    ULONG   ulSensor;
    LONG    lIn[64];
    LONG    lOut[64];
}
XAD244I_LIN_TABLE, *PXAD244I_LIN_TABLE;

// Message MDD
typedef struct
{
    USHORT   usDevice;
    USHORT   usFlags;
    USHORT   usSLN;
    USHORT	usInterface;
	ULONG		ulAddress;
    USHORT   usSrqWord;
    ULONG    ulLibHandle;
}
CPS_X_MSG, *PCPS_X_MSG;

// X-5bx64-8
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT	usAddress;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
}
CPS_X5BX648, *PCPS_X5BX648;

#define X5BX648_SAMPLE_TRIGGER		0x0
#define X5BX648_WATCHDOG_TRIGGER	0x1
#define X5BX648_STATUS				0x0
#define X5BX648_STATUS_OK			0x0
#define X5BX648_STATUS_WARNING		0x1
#define X5BX648_STATUS_ERROR		0x2
#define X5BX648_MODULE_ADDRESS		0xFFFF

// X-CPLD-38
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usRegisterWidth;
   USHORT   usFlags;
   USHORT   usMode;
   USHORT   usReadMode;
   USHORT   usWriteMode;
}
CPS_XCPLD38, *PCPS_XCPLD38;

#define XCPLD38_BYTE_REGISTER       0x1
#define XCPLD38_WORD_REGISTER       0x2

// BASiS-6
typedef struct
{
   USHORT   usVersion;
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usRegisterWidth;
   ULONG    ulFlags;
   USHORT   usMode;
   USHORT   usReadMode;
   USHORT   usWriteMode;
}
CPS_BASIS6, *PCPS_BASIS6;

#define BASIS6_WORD_REGISTER       0x1


// X-CAN-2
typedef struct
{
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT	usIndexLast;
	USHORT	usChannel;		// CAN-Controller 0 or 1
   ULONG		ulCanID;
   USHORT   usFlags;
   USHORT	usTimeout;
}
CPS_XCAN, *PCPS_XCAN;

#define XCAN_BUS_ON         0x0000
#define XCAN_BUS_OFF        0x0002
#define XCAN_BUS_HEAVY      0x0001
#define XCAN_LINE_ERROR     0x0004

#define XCAN_BUS_CTRL_INDEX   100
#define XCAN_MIXED_FORMAT     0xAB

#define XCAN_GENERAL_ID     0xFFFFFFFFl
#define XCAN_AUTO_ID        0xFFFFFFFFl

typedef struct
{
   USHORT   Tq;
   USHORT   Tseg1;
   USHORT   Tseg2;
   USHORT   Tsjw;
   USHORT   SpB;
   USHORT	Rbus;
	USHORT	MsgFormat;	
}
XCAN_BIT_PARAMS;

typedef struct
{
   ULONG		ulCanId;
   USHORT   usFlags;	
   USHORT   usDataSize;
   UCHAR		aucData[8];
}
XCAN_MESSAGE;

// X-COM-4
typedef struct
{
   USHORT   usDevice;
   USHORT   usType;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   ULONG    ulFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usFlowControl;
   ULONG    ulBaudRate;
   USHORT   usByteSize;
   USHORT   usStopBits;
   USHORT   usParity;
   ULONG    ulXonLim;
   ULONG    ulXoffLim;
   CHAR     cXonChar;
   CHAR     cXoffChar;
   CHAR     cErrorChar;
   ULONG    ulTmtBuffer;
   ULONG    ulRcvBuffer;
   ULONG    ulTimeout;
   ULONG    ulCallBackEvents;
}
CPS_XCOM4, *PCPS_XCOM4;

#define _XCOM4_ERROR_OVERRUN                0x0001
#define _XCOM4_ERROR_FRAME                  0x0002
#define _XCOM4_ERROR_BREAK                  0x0004
#define _XCOM4_ERROR_RCV_BUFFER_OVERFLOW    0x0008
#define _XCOM4_ERROR_PARITY                 0x0010
#define _XCOM4_ERROR_TMT                    0x0020

#define _XCOM4_DTR_0                        0x00000001
#define _XCOM4_DTR_1                        0x00000002
#define _XCOM4_RTS_0                        0x00000004
#define _XCOM4_RTS_1                        0x00000008

#define _XCOM4_DCTS                         0x1
#define _XCOM4_DDSR                         0x2
#define _XCOM4_DRI                          0x4
#define _XCOM4_DDCD                         0x8
#define _XCOM4_CTS                          0x10
#define _XCOM4_DSR                          0x20
#define _XCOM4_RI                           0x40
#define _XCOM4_DCD                          0x80

#define _XCOM4_EVENT_RCV_BUFFER             0x00000001
#define _XCOM4_EVENT_TMT_BUFFER             0x00000002
#define _XCOM4_EVENT_RCV_ERROR              0x00000004
#define _XCOM4_EVENT_BREAK                  0x00000008
#define _XCOM4_EVENT_RCV_CHAR               0x00000010
#define _XCOM4_EVENT_RCV_BUFFER_OVERFLOW    0x00000020

// X-COM-8
typedef struct
{
   USHORT   usDevice;
   USHORT   usType;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   ULONG    ulFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usFlowControl;
   ULONG    ulBaudRate;
   USHORT   usByteSize;
   USHORT   usStopBits;
   USHORT   usParity;
   ULONG    ulXonLim;
   ULONG    ulXoffLim;
   CHAR     cXonChar;
   CHAR     cXoffChar;
   CHAR     cErrorChar;
   ULONG    ulTmtBuffer;
   ULONG    ulRcvBuffer;
   ULONG    ulTimeout;
   ULONG    ulCallBackEvents;
}
CPS_XCOM8, *PCPS_XCOM8;

#define _XCOM8_ERROR_OVERRUN                0x0001
#define _XCOM8_ERROR_FRAME                  0x0002
#define _XCOM8_ERROR_BREAK                  0x0004
#define _XCOM8_ERROR_RCV_BUFFER_OVERFLOW    0x0008
#define _XCOM8_ERROR_PARITY                 0x0010
#define _XCOM8_ERROR_TMT                    0x0020

#define _XCOM8_RTS_0                        0x00000004
#define _XCOM8_RTS_1                        0x00000008

#define _XCOM8_DCTS                         0x1
#define _XCOM8_DDSR                         0x2
#define _XCOM8_DRI                          0x4
#define _XCOM8_DDCD                         0x8
#define _XCOM8_CTS                          0x10
#define _XCOM8_RI                           0x40
#define _XCOM8_DCD                          0x80

#define _XCOM8_EVENT_RCV_BUFFER             0x00000001
#define _XCOM8_EVENT_TMT_BUFFER             0x00000002
#define _XCOM8_EVENT_RCV_ERROR              0x00000004
#define _XCOM8_EVENT_BREAK                  0x00000008
#define _XCOM8_EVENT_RCV_CHAR               0x00000010
#define _XCOM8_EVENT_RCV_BUFFER_OVERFLOW    0x00000020


// X-OSRAM-8
typedef struct
{
   USHORT   usVersion;
   USHORT   usDevice;
   USHORT   usType;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   ULONG    ulFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usFlowControl;
   ULONG    ulBaudRate;
   USHORT   usByteSize;
   USHORT   usStopBits;
   USHORT   usParity;
   ULONG    ulXonLim;
   ULONG    ulXoffLim;
   CHAR     cXonChar;
   CHAR     cXoffChar;
   CHAR     cErrorChar;
   ULONG    ulTmtBuffer;
   ULONG    ulRcvBuffer;
   ULONG    ulTimeout;
   ULONG    ulCallBackEvents;
}
CPS_XOSRAM8, *PCPS_XOSRAM8;

#define _XOSRAM8_ERROR_OVERRUN                0x0001
#define _XOSRAM8_ERROR_FRAME                  0x0002
#define _XOSRAM8_ERROR_BREAK                  0x0004
#define _XOSRAM8_ERROR_RCV_BUFFER_OVERFLOW    0x0008
#define _XOSRAM8_ERROR_PARITY                 0x0010
#define _XOSRAM8_ERROR_TMT                    0x0020

#define _XOSRAM8_RTS_0                        0x00000004
#define _XOSRAM8_RTS_1                        0x00000008

#define _XOSRAM8_DCTS                         0x1
#define _XOSRAM8_DDSR                         0x2
#define _XOSRAM8_DRI                          0x4
#define _XOSRAM8_DDCD                         0x8
#define _XOSRAM8_CTS                          0x10
#define _XOSRAM8_RI                           0x40
#define _XOSRAM8_DCD                          0x80

#define _XOSRAM8_EVENT_RCV_BUFFER             0x00000001
#define _XOSRAM8_EVENT_TMT_BUFFER             0x00000002
#define _XOSRAM8_EVENT_RCV_ERROR              0x00000004
#define _XOSRAM8_EVENT_BREAK                  0x00000008
#define _XOSRAM8_EVENT_RCV_CHAR               0x00000010
#define _XOSRAM8_EVENT_RCV_BUFFER_OVERFLOW    0x00000020

// X-DPS-2
typedef struct
{
   USHORT   usDevice;
   USHORT   usChannel;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usAddress;
   USHORT   usFlags;
   USHORT   usMode;
   USHORT   usTimeout;
}
CPS_XDPS, *PCPS_XDPS;

// mode for diagnosis channel
#define XDPS_DIAG_FOR_DEVICE	   0
#define XDPS_DIAG_FOR_ID	      1
#define XDPS_DIAG_FOR_CHANNEL    2

// Event callback messages
#define XDPS_PARAM_ERROR   1     // no further info
#define XDPS_CFG_ERROR     2     // high byte is offset of the first wrong byte
#define XDPS_OFFLINE       3     // no further info
#define XDPS_DATA_XCHG     4     // high byte is DP STATE in bit 4 and 5
#define XDPS_RCV_CTRL_CMD  5     // high byte is type of command (sync, freeze...)
#define XDPS_NEW_DATA      6     // no further info
#define XDPS_SLAVE_ADDR    7     // high byte contains new slave address
#define XDPS_BAUDRATE_DETECT   8 // high byte contains new baudrate in SPC3 code 
#define XDPS_WATCHDOG_TIMEOUT  9 // no further info 

// constants for X-ETH-10
#define	XETH_MAC_ADDRESS		0
#define	XETH_ADAPTER_SETTING	1
#define	XETH_IP_SETTING		2
#define	XETH_HALF_DUPLEX_10	0
#define	XETH_FULL_DUPLEX_10	1
#define	XETH_TCP_SERVER		0
#define	XETH_TCP_CLIENT		1
#define	XETH_LISTEN				0
#define	XETH_CONNECTING		1
#define	XETH_ESTABLISHED		2
#define	XETH_CLOSING			3
#define	XETH_CLOSED				4

#define  XETH_EVENT_ESTABLISHED  1
#define  XETH_EVENT_CLOSED       2
#define  XETH_EVENT_NEW_DATA     4
///////////////////////////////////////////////////////////////////////////////
typedef struct
{
   USHORT   usVersion;
   USHORT	usTransMode;
}
XETH_ADAPTER_SETTINGS;
///////////////////////////////////////////////////////////////////////////////
typedef struct
{
   USHORT   usVersion;
   ULONG		ulIp;
   ULONG		ulSubnetmask;
   ULONG		ulGateway;
}
XETH_IP_SETTINGS;
///////////////////////////////////////////////////////////////////////////////
typedef struct
{
   USHORT   usVersion;
   USHORT   usDevice;
   USHORT   usIndex;
   USHORT   usFlags;
   ULONG    ulCallbackEvents;
   USHORT   usType;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   ULONG    ulServerIp;
   USHORT   usServerPort;
}
CPS_XETH, *PCPS_XETH;

///////////////////////////////////////////////////////////////////////////////
typedef struct
{
   USHORT   usVersion;
   USHORT   usChannel;      
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   USHORT   usType;
   USHORT   usTRxC;
   USHORT   usRTxC;
   USHORT   usMode;
}
CPS_XSCC2, *PCPS_XSCC2;

// definitions for register channel
#define XSCC_WR7_PRIME  77

// definitions for the CPS of the module control/configuration channel
#define XSCC_CTRL_PHYS_IFC  1

#define XSCC_SEL_NC     0
#define XSCC_SEL_PCLK   0
#define XSCC_SEL_CLKIO  1
#define XSCC_SEL_CTS    2
#define XSCC_SEL_RI     3

// definitions for usMode of the interrupt channel and the callback function
#define XSCC_INT_RCA          0x0001
#define XSCC_INT_TBE          0x0002
#define XSCC_INT_SPEC_COND    0x0070   // includes the following bits
#define XSCC_INT_SPEC_EOF     0x0010
#define XSCC_INT_SPEC_FRAME   0x0020   
#define XSCC_INT_FRAME_ERR    0x0020
#define XSCC_INT_CRC_ERR      0x0020
#define XSCC_INT_SPEC_OVERRUN 0x0040   
#define XSCC_INT_PARITY_ERR   0x0080
#define XSCC_INT_BRK          0x0100
#define XSCC_INT_TMTUR_EOM    0x0200
#define XSCC_INT_CTS          0x0400
#define XSCC_INT_SYNC         0x0800
#define XSCC_INT_DCD          0x1000
#define XSCC_INT_ZERO         0x2000

// Bit definitions for the SCC regs 
// WR0 commands 
#define XSCC_RESET_IUS          0x38
#define XSCC_RESET_ERR          0x30
#define XSCC_RESET_TXIP         0x28
#define XSCC_ENABLE_INT_ON_NEXT_RX  0x20
#define XSCC_SEND_ABORT         0x18
#define XSCC_RESET_EXSTIP       0x10
#define XSCC_RESET_RX_CRC       0x40
#define XSCC_RESET_TX_CRC       0x80
#define XSCC_RESET_TXUR_EOM     0xC0

// WR1 interrupt control
#define XSCC_IE_FIRST_RCA       0x08    // and spec. cond.
#define XSCC_IE_ALL_RCA         0x10    // and spec. cond.
#define XSCC_IE_SPEC_COND       0x18
#define XSCC_PARITY_IS_SPEC_COND 0x04
#define XSCC_IE_TBE             0x02
#define XSCC_IE_EXT             0x01

// WR2/RR2 interrupt vector
// the following defines are valid if VIS in WR9 is set
#define XSCC_INTPND_CHL_SEL 0x08    // selects if channel 0 or 1 has int. pending
#define XSCC_INTPND_REASON  0x06    // mask for the following bits
#define XSCC_INTPND_TBE     0x00
#define XSCC_INTPND_EXT     0x02
#define XSCC_INTPND_RCA     0x04
#define XSCC_INTPND_SPRC    0x06

// WR3 receive parameter/control
#define XSCC_RX_ENABLE              0x01
#define XSCC_SYNC_CHAR_LOAD_INHIBIT 0x02
#define XSCC_ADDR_SEARCH_MODE       0x04
#define XSCC_RX_CRC_ENABLE          0x08
#define XSCC_ENTER_HUNT_MODE        0x10
#define XSCC_AUTO_ENABLES           0x20
#define XSCC_RX_5_BPC               0x00
#define XSCC_RX_6_BPC               0x80
#define XSCC_RX_7_BPC               0x40
#define XSCC_RX_8_BPC               0xC0

// WR4/RR4 modes
#define XSCC_PARITY_ENABLE          0x01
#define XSCC_EVEN_PARITY            0x02
#define XSCC_SYNC_MODE              0x00
#define XSCC_STOP_BIT_1             0x04
#define XSCC_STOP_BIT_1_5           0x08
#define XSCC_STOP_BIT_2             0x0C
#define XSCC_MODE_MONOSYNC          0x00            
#define XSCC_MODE_BISYNC            0x10
#define XSCC_MODE_SDLC              0x20
#define XSCC_MODE_EXT_SYNC          0x30            
#define XSCC_X1_CLOCK_MODE          0x00
#define XSCC_X16_CLOCK_MODE         0x40
#define XSCC_X32_CLOCK_MODE         0x80
#define XSCC_X64_CLOCK_MODE         0xC0

// WR5/RR5 transmit parameter/control
#define XSCC_TX_CRC_ENABLE          0x01
#define XSCC_RTS_CONTROL            0x02
#define XSCC_CRC_SELECT             0x04
#define XSCC_TX_ENABLE              0x08
#define XSCC_SEND_BREAK             0x10
#define XSCC_TX_5_BPC               0x00
#define XSCC_TX_6_BPC               0x40
#define XSCC_TX_7_BPC               0x20
#define XSCC_TX_8_BPC               0x60
#define XSCC_DTR_CONTROL            0x80

// WR7 Prime (D0 in WR15 must be 1)
#define XSCC_AUTO_TX_SDLC_FLAG  0x01
#define XSCC_AUTO_EOM_RESET     0x02
#define XSCC_AUTO_RTS_DEACT     0x04
#define XSCC_RCV_INT_HALFFIFO   0x08
#define XSCC_DTRREQTIME         0x10
#define XSCC_TMT_INT_TBE        0x20
#define XSCC_EXTENDED_RD_ENABLE 0x40

// WR9 master interrupt control
#define XSCC_VIS 		    0x01
#define XSCC_NV 		    0x02
#define XSCC_DLC 		    0x04
#define XSCC_MIE 		    0x08
#define XSCC_STHI 		    0x10
#define XSCC_SWIACKEN       0x20
#define XSCC_CHL_RESET_1    0x40
#define XSCC_CHL_RESET_0    0x80
#define XSCC_HARDWARE_RESET 0xC0

// WR10 misc. control bits
#define XSCC_SYNC_CHAR_6BIT     0x01
#define XSCC_LOOP_MODE          0x02
#define XSCC_ABORT_ON_UNDERRUN  0x04
#define XSCC_MARK_ON_IDLE       0x08
#define XSCC_GO_ACTIVE_ON_POLL  0x10
#define XSCC_BIT_CODE_NRZ       0x00
#define XSCC_BIT_CODE_NRZI      0x20
#define XSCC_BIT_CODE_FM1       0x40
#define XSCC_BIT_CODE_FM0       0x60
#define XSCC_CRC_PRESET_1       0x80

// WR11 clock control
#define XSCC_TRXC_OUT_XTAL      0x00
#define XSCC_TRXC_OUT_TMTCLK    0x01
#define XSCC_TRXC_OUT_BRG       0x02
#define XSCC_TRXC_OUT_DPLL      0x03
#define XSCC_TRXC_DIR_CTRL      0x04
#define XSCC_TMTCLK_RTXC        0x00
#define XSCC_TMTCLK_TRXC        0x08
#define XSCC_TMTCLK_BRG         0x10
#define XSCC_TMTCLK_DPLL        0x18
#define XSCC_RCVCLK_RTXC        0x00
#define XSCC_RCVCLK_TRXC        0x20
#define XSCC_RCVCLK_BRG         0x40
#define XSCC_RCVCLK_DPLL        0x60
#define XSCC_RTXC_XTAL_SEL      0x80

// WR14 misc. control bits
#define XSCC_BRG_ENABLE         0x01
#define XSCC_BRG_SEL_PCLK       0x02
#define XSCC_DTR_ON_TBE         0x04
#define XSCC_DTR_ON_CRC_SENT    0x04
#define XSCC_AUTO_ECHO          0x08
#define XSCC_LOCAL_LOOPBACK     0x10
#define XSCC_ENTER_SEARCH_MODE  0x20
#define XSCC_RESET_MISSING_CLK  0x40
#define XSCC_DISABLE_DPLL       0x60
#define XSCC_SET_SOURCE_BRG     0x80
#define XSCC_SET_SOURCE_RTXC    0xA0
#define XSCC_SET_FM_MODE        0xC0
#define XSCC_SET_NRZI_MODE      0xE0

// WR15//RR15 ext/status interrupt control
#define XSCC_POINT_WR7PRIME 	0x01
#define XSCC_IE_ZERO_COUNT		0x02
#define XSCC_STATUS_FIFO_ENABLE 0x04
#define XSCC_IE_DCD		        0x08
#define XSCC_IE_SYNC	        0x10
#define XSCC_IE_CTS 	        0x20
#define XSCC_IE_TMTUR_EOM       0x40
#define XSCC_IE_BREAK           0x80
#define XSCC_IE_ABORT           0x80

// RR0 status
#define  XSCC_STATE_RCA		0x01
#define  XSCC_STATE_ZC		0x02
#define  XSCC_STATE_TBE		0x04
#define  XSCC_STATE_DCD		0x08
#define  XSCC_STATE_SYNC	    0x10
#define  XSCC_STATE_HUNT	    0x10
#define  XSCC_STATE_CTS		0x20
#define  XSCC_STATE_TXUR	    0x40
#define  XSCC_STATE_EOM		0x40
#define  XSCC_STATE_BREAK	0x80
#define  XSCC_STATE_ABORT	0x80

// RR1 status
#define  XSCC_ALL_SENT		0x01
#define  XSCC_RESIDUE_CODE	0x0E
#define  XSCC_PARITY_ERROR	0x10
#define  XSCC_OVERRUN_ERROR 0x20
#define  XSCC_FRAME_ERROR	0x40
#define  XSCC_CRC_ERROR		0x40
#define  XSCC_EOF			0x80

// RR3 interrupt pending
#define  XSCC_RR2_INTPND_EXT_1     0x01
#define  XSCC_RR2_INTPND_TBE_1     0x02
#define  XSCC_RR2_INTPND_RCV_1     0x04
#define  XSCC_RR2_INTPND_EXT_0     0x08
#define  XSCC_RR2_INTPND_TBE_0     0x10
#define  XSCC_RR2_INTPND_RCV_0     0x20

typedef struct
{
   USHORT   usVersion;
   USHORT   usDevice;
   USHORT   usIndexFirst;
   USHORT   usIndexLast;
   USHORT   usType;
   ULONG    ulFlags;
   USHORT   usReadMode;
   USHORT   usWriteMode;
   ULONG    ulBaudRate;
   USHORT   usFlowControl;
   USHORT   usDataSize;
   USHORT   usStopBits;
   USHORT   usParity;
   ULONG    ulXonLim;
   ULONG    ulXoffLim;
   CHAR     cXonChar;
   CHAR     cXoffChar;
   CHAR     cErrorChar;
   CHAR     cFree;
   ULONG    ulTmtBuffer;
   ULONG    ulRcvBuffer;
   ULONG    ulCallBackEvents;
   USHORT   usChipSelectDevice;
}
CPS_XMAX400, *PCPS_XMAX400;

// Flags
#define _XMAX400_EVENT_POS_EDGE        0x00000001
#define _XMAX400_EVENT_NEG_EDGE        0x00000002

#define _XMAX400_SPI_POLARITY_HIGH     0x00000010
#define _XMAX400_SPI_PHASE_END         0x00000008
#define _XMAX400_SSP_EXTERNAL_CLOCK    0x00000020
#define _XMAX400_SSP_CLOCK_FREE_RUN    0x00000100
#define _XMAX400_SSP_SLAVE_MODE_CLOCK  0x00000200
#define _XMAX400_SSP_SLAVE_MODE_FRAME  0x00000400

#define _XMAX400_ERROR_OVERRUN          0x0001
#define _XMAX400_ERROR_FRAME            0x0002
#define _XMAX400_ERROR_BREAK            0x0004
#define _XMAX400_ERROR_RCVBUF_OVERRUN   0x0008
#define _XMAX400_ERROR_PARITY           0x0010
#define _XMAX400_ERROR_TMT              0x0020
#define _XMAX400_ERROR_BITCOUNT         0x0040
#define _XMAX400_ERROR_TMT_UNDERRUN     0x0080

#define _XMAX400_DTR_0                  0x00000001
#define _XMAX400_DTR_1                  0x00000002
#define _XMAX400_RTS_0                  0x00000004
#define _XMAX400_RTS_1                  0x00000008

#define _XMAX400_DCTS                   0x1
#define _XMAX400_DDSR                   0x2
#define _XMAX400_DRI                    0x4
#define _XMAX400_DDCD                   0x8
#define _XMAX400_CTS                    0x10
#define _XMAX400_DSR                    0x20
#define _XMAX400_RI                     0x40
#define _XMAX400_DCD                    0x80

#define _XMAX400_EVENT_RCV_BUFFER       0x00000001
#define _XMAX400_EVENT_TMT_BUFFER       0x00000002
#define _XMAX400_EVENT_RCV_ERROR        0x00000004
#define _XMAX400_EVENT_BREAK            0x00000008
#define _XMAX400_EVENT_RCV_CHAR         0x00000010
#define _XMAX400_EVENT_RCVBUF_OVERRUN   0x00000020
#define _XMAX400_EVENT_ERROR            0x00000040

// index settings
#define XMAX400_COMF 0
#define XMAX400_COMB 1
#define XMAX400_COMS 2

#define XMAX400_SSP1 0
#define XMAX400_SSP2 1

#define XMAX400_TIMER_1 1

// usType selection for DEVICE_SSP
#define SSP_TYPE_SPI            0x0000
#define SSP_TYPE_SSP            0x0001
#define SSP_TYPE_MW             0x0002

#define XMAX400_DEVICE_INDEX_PIN_A01	101
#define XMAX400_DEVICE_INDEX_PIN_A02	102
#define XMAX400_DEVICE_INDEX_PIN_A03	103
#define XMAX400_DEVICE_INDEX_PIN_A04	104
#define XMAX400_DEVICE_INDEX_PIN_A05	105
#define XMAX400_DEVICE_INDEX_PIN_A06	106
#define XMAX400_DEVICE_INDEX_PIN_A07	107
#define XMAX400_DEVICE_INDEX_PIN_A08	108
#define XMAX400_DEVICE_INDEX_PIN_A09	109
#define XMAX400_DEVICE_INDEX_PIN_A10	110
#define XMAX400_DEVICE_INDEX_PIN_A11	111
#define XMAX400_DEVICE_INDEX_PIN_A12	112
#define XMAX400_DEVICE_INDEX_PIN_A13	113
#define XMAX400_DEVICE_INDEX_PIN_A14	114
#define XMAX400_DEVICE_INDEX_PIN_A15	115
#define XMAX400_DEVICE_INDEX_PIN_A16	116
#define XMAX400_DEVICE_INDEX_PIN_A17	117
#define XMAX400_DEVICE_INDEX_PIN_A18	118
#define XMAX400_DEVICE_INDEX_PIN_A19	119
#define XMAX400_DEVICE_INDEX_PIN_A20	120
#define XMAX400_DEVICE_INDEX_PIN_A21	121
#define XMAX400_DEVICE_INDEX_PIN_A22	122
#define XMAX400_DEVICE_INDEX_PIN_A23	123
#define XMAX400_DEVICE_INDEX_PIN_A24	124
#define XMAX400_DEVICE_INDEX_PIN_A25	125
#define XMAX400_DEVICE_INDEX_PIN_A26	126
#define XMAX400_DEVICE_INDEX_PIN_A27	127
#define XMAX400_DEVICE_INDEX_PIN_A28	128
#define XMAX400_DEVICE_INDEX_PIN_A29	129
#define XMAX400_DEVICE_INDEX_PIN_A30	130
#define XMAX400_DEVICE_INDEX_PIN_A31	131
#define XMAX400_DEVICE_INDEX_PIN_A32	132
#define XMAX400_DEVICE_INDEX_PIN_A33	133
#define XMAX400_DEVICE_INDEX_PIN_A34	134
#define XMAX400_DEVICE_INDEX_PIN_A35	135
#define XMAX400_DEVICE_INDEX_PIN_A36	136
#define XMAX400_DEVICE_INDEX_PIN_A37	137
#define XMAX400_DEVICE_INDEX_PIN_A38	138
#define XMAX400_DEVICE_INDEX_PIN_A39	139
#define XMAX400_DEVICE_INDEX_PIN_A40	140

#define XMAX400_DEVICE_INDEX_PIN_C01	141
#define XMAX400_DEVICE_INDEX_PIN_C02	142
#define XMAX400_DEVICE_INDEX_PIN_C03	143
#define XMAX400_DEVICE_INDEX_PIN_C04	144
#define XMAX400_DEVICE_INDEX_PIN_C05	145
#define XMAX400_DEVICE_INDEX_PIN_C06	146
#define XMAX400_DEVICE_INDEX_PIN_C07	147
#define XMAX400_DEVICE_INDEX_PIN_C08	148
#define XMAX400_DEVICE_INDEX_PIN_C09	149
#define XMAX400_DEVICE_INDEX_PIN_C10	150
#define XMAX400_DEVICE_INDEX_PIN_C11	151
#define XMAX400_DEVICE_INDEX_PIN_C12	152
#define XMAX400_DEVICE_INDEX_PIN_C13	153
#define XMAX400_DEVICE_INDEX_PIN_C14	154
#define XMAX400_DEVICE_INDEX_PIN_C15	155
#define XMAX400_DEVICE_INDEX_PIN_C16	156
#define XMAX400_DEVICE_INDEX_PIN_C17	157
#define XMAX400_DEVICE_INDEX_PIN_C18	158
#define XMAX400_DEVICE_INDEX_PIN_C19	159
#define XMAX400_DEVICE_INDEX_PIN_C20	160
#define XMAX400_DEVICE_INDEX_PIN_C21	161
#define XMAX400_DEVICE_INDEX_PIN_C22	162
#define XMAX400_DEVICE_INDEX_PIN_C23	163
#define XMAX400_DEVICE_INDEX_PIN_C24	164
#define XMAX400_DEVICE_INDEX_PIN_C25	165
#define XMAX400_DEVICE_INDEX_PIN_C26	166
#define XMAX400_DEVICE_INDEX_PIN_C27	167
#define XMAX400_DEVICE_INDEX_PIN_C28	168
#define XMAX400_DEVICE_INDEX_PIN_C29	169
#define XMAX400_DEVICE_INDEX_PIN_C30	170
#define XMAX400_DEVICE_INDEX_PIN_C31	171
#define XMAX400_DEVICE_INDEX_PIN_C32	172
#define XMAX400_DEVICE_INDEX_PIN_C33	173
#define XMAX400_DEVICE_INDEX_PIN_C34	174
#define XMAX400_DEVICE_INDEX_PIN_C35	175
#define XMAX400_DEVICE_INDEX_PIN_C36	176
#define XMAX400_DEVICE_INDEX_PIN_C37	177
#define XMAX400_DEVICE_INDEX_PIN_C38	178
#define XMAX400_DEVICE_INDEX_PIN_C39	179
#define XMAX400_DEVICE_INDEX_PIN_C40	180

#define XMAX400_DEVICE_INDEX_DEFAULT	0

typedef struct _CALIB_DATA
{
   USHORT   usVersion;          // version of struct = 1
   LONG     lRefval1;           // reference value 1 (normalized format)
   LONG     lActval1;           // actual value 1 (normalized format)
   LONG     lRefval2;           // reference value 2 (normalized format)
   LONG     lActval2;           // actual value 2 (normalized format)
}
CALIB_DATA, *PCALIB_DATA;

typedef struct _XAD164_CALIB_PARAMETER
{
    USHORT  usVersion;
    CHAR    acText[10];
    ULONG   ulDate;
    ULONG   ulTime;
    LONG    lTemp;              // read only
    ULONG   ulMddVersion;       // read only
}
XAD164_CALIB_PARAMETER, *PXAD164_CALIB_PARAMETER;

typedef struct _XDAD4_CALIB_PARAMETER
{
    USHORT  usVersion;
    CHAR    acText[10];
    ULONG   ulDate;
    ULONG   ulTime;
    LONG    lTemp;              // read only
    ULONG   ulMddVersion;       // read only
}
XDAD4_CALIB_PARAMETER, *PDAD4_CALIB_PARAMETER;

typedef struct _XTEST1_CALIB_PARAMETER
{
    USHORT  usVersion;
    CHAR    acText[10];
    ULONG   ulDate;
    ULONG   ulTime;
    LONG    lTemp;              // read only
    ULONG   ulMddVersion;       // read only
}
XTEST1_CALIB_PARAMETER, *PXTEST1_CALIB_PARAMETER;

typedef struct _XDA164_CALIB_PARAMETER
{
    USHORT  usVersion;
    CHAR    acText[10];
    ULONG   ulDate;
    ULONG   ulTime;
    LONG    lTemp;              // read only
    ULONG   ulMddVersion;       // read only
}
XDA164_CALIB_PARAMETER, *PXDA164_CALIB_PARAMETER;

typedef struct _XAD244I_CALIB_PARAMETER
{
    USHORT  usVersion;
    CHAR    acText[10];
    ULONG   ulDate;
    ULONG   ulTime;
    LONG    lTemp;              // read only
    ULONG   ulMddVersion;       // read only
}
XAD244I_CALIB_PARAMETER, *PXAD244I_CALIB_PARAMETER;

#ifndef MDD_CORRECTION_DEFINED //CB 26.3.2004
#define MDD_CORRECTION_DEFINED
typedef struct _MDD_CORRECTION
{
   USHORT   usRange;
   USHORT   usNormalizer;
   LONG     lNormalizedGain;
   LONG     lNormalizedOffset;
}
MDD_CORRECTION, *PMDD_CORRECTION;
#endif


// identification of a MSG_MDD_DATA data structure in the library
#define MSGMDD_DATA_KEY        0x4B444D4DL //"MMDK"

#ifndef __BORLANDC__
   #ifdef PLATFORM_LINUX
   #ifndef HANDLE_SYSV_PRAGMA
	          #define HANDLE_SYSV_PRAGMA 4
	 #endif
      #pragma pack(4)
   #else
      #pragma pack(pop, SORCPACK)
   #endif
#else
   #ifndef _RTLIB_
      #ifndef PLATFORM_OSX
         #pragma option -a8
      #endif
   #endif
#endif

#endif // _INC_X_MDD_H

