/********************************************************************
*  X_TYPES.H
*
*  This header file defines data types used by the SORCUS libraries
*  for the MAX-system.
*
*  Copyrights:          SORCUS Computer GmbH 2001
*                       All Rights Reserved
********************************************************************/
/*
History: 12.12.02 new: MAX_FILE_WRITE_TYPE, MAX_DRIVE_INFO and MAX_FILE16_INFO_TYPE
*/
#ifndef _INC_X_TYPES_H
#define _INC_X_TYPES_H

#include "x_defs.h"

#ifdef _RTLIB_
   #define USHORT unsigned short
   #define SHORT  signed short
   #define ULONG  unsigned long
   #define LONG   signed long
   #define UCHAR  unsigned char
   #define CHAR   char
#endif

typedef  unsigned long  MAXMODHND; // handle for CPU-module: retrieved by max_connect_cpu
typedef  unsigned long  MAXMDDHND; // handle for MDD: retrieved by max_load_mdd
typedef  unsigned long  MAXCHLHND; // handle for MDD channel: retrieved by max_open_channel
typedef  unsigned long  MAXCHMHND; // handle for channel manager channel: retrieved by max_open_chm_channel
typedef  unsigned long  MAXBUFHND; // handle for buffer: retrieved by max_create_buffer
typedef  unsigned long  MAXTASKHND; // handle for buffer: retrieved by max_install_task

#ifdef _RTLIB_
	#define MAX_CALLBACK void far pascal
	typedef void (far pascal *MAX_CHANNEL_CALLBACK_TYPE)(MAXCHLHND hChannel, ULONG ulPar, ULONG ulSize, void *pMsg);
	typedef void (far pascal *MAX_CALLBACK_TYPE)(void *mvx, ULONG ulMsg);
	typedef void (far pascal *MAX_RTFUNCTION_TYPE)(USHORT *pusInsize, void *pDataIn, USHORT *pusOutsize, void *pDataOu);
#else
	#define MAX_CALLBACK void _stdcall
	typedef void (_stdcall *MAX_CHANNEL_CALLBACK_TYPE)(MAXCHLHND hChannel, ULONG ulPar, ULONG ulSize, void *pMsg);
	typedef void (_stdcall *MAX_CALLBACK_TYPE)(MAXMODHND hModul, ULONG ulMsg);
#endif


typedef  unsigned short MAX_ERROR;	 // error code, possible values x_error.h	
// version information, format:
// byte 3:		Version (1..255)
// byte 2:		Revision ('A'..'Z' = 41h..5Ah)
// byte 0-1:	Revision counter (0..65535)
typedef  unsigned long  MAX_VERSION;

// all structs are word aligned
#ifdef PLATFORM_LINUX           //CB
        #ifndef HANDLE_SYSV_PRAGMA
	          #define HANDLE_SYSV_PRAGMA 1
	      #endif
        #pragma pack(2) //CB
#else                           //CB
   #ifndef __BORLANDC__
      #pragma pack(push, SORCPACK, 2)
   #else
      #ifndef _RTLIB_
         #pragma option -a1
      #endif
   #endif
#endif                          //CB


typedef struct _MAX_LONG
{
    UCHAR ucLowByte;
    UCHAR ucByte1;
    UCHAR ucByte2;
    UCHAR ucHighByte;
} MAX_LONG;

typedef struct _MAX_INT
{
    UCHAR ucLowByte;
    UCHAR ucHighByte;
} MAX_INT;

typedef struct _MAX_BUFFER_TYPE {
   USHORT   usStrategy;
	USHORT   usAlignment;
	USHORT   usTask;           
	USHORT   usUsage;           
} MAX_BUFFER_TYPE;

typedef MAX_BUFFER_TYPE MAX_ALLOC_TYPE;

typedef struct _MAX_OS_INFO {
	USHORT	usType;							// which os is active
	MAX_VERSION	Version;						// version code
	ULONG		ulSub;							// reserved for os with more version info
	ULONG		ulDate;							// date of making
} MAX_OS_INFO;

typedef struct _MAX_TI_TYPE {
	USHORT   usPriority;
	ULONG    ulHoldOff;
	ULONG    ulIntervall;
	ULONG    ulCalls;
} MAX_TI_TYPE;

typedef struct _MAX_TIME_TYPE {
   USHORT   sec;     /* seconds after the minute - [0,59] */
   USHORT   min;     /* minutes after the hour - [0,59] */
   USHORT   hour;    /* hours since midnight - [0,23] */
   USHORT   mday;    /* day of the month - [1,31] */
   USHORT   mon;     /* months since January - [1,12] */
   USHORT   year;    /* years since 0 */
   USHORT   wday;    /* days since Sunday - [0,6] */
} MAX_TIME_TYPE;

typedef struct _MAX_ALARM_TYPE {
   USHORT   sec;     /* seconds after the minute - [0,59] */
   USHORT   min;     /* minutes after the hour - [0,59] */
   USHORT   hour;    /* hours since midnight - [0,23] */
} MAX_ALARM_TYPE;

typedef struct _MAX_DEV_SPEC_TYPE {
	ULONG		ulType;
	ULONG		ulIndex;
	ULONG		ulSubIndex;
} MAX_DEV_SPEC_TYPE;

typedef struct _MAX_PGM_TYPE 
{
	char		*szName;
	USHORT	usNo;
	USHORT	usUsage;
	USHORT	usTask;
	USHORT	usTaskType;
	USHORT	usLevel;
	USHORT	usIrq;
	USHORT	usFlags;
	ULONG		ulDataSize;
} MAX_PGM_TYPE;

typedef struct _MAX_MODULINFO_TYPE 
{
	USHORT   usType;
	USHORT   usVariant;
   USHORT   usReserved;
	USHORT	usVersion;
   USHORT   usCategory;
	USHORT   usStatus;
} MAX_MODULINFO_TYPE;

typedef struct _MAX_BOARD_TYPE 
{
	USHORT		usType;
   USHORT      usReserved;
	USHORT	   usVersion;
	ULONG			ulSerNr;
} MAX_BOARD_TYPE;


typedef struct _MAX_CONNECTION_TYPE 
{
	USHORT		usBoardNumber;
   USHORT      usConnectionType;
} MAX_CONNECTION_TYPE;

typedef struct _MAX_FLASH_TYPE 
{
	USHORT	usManufacturer;
	USHORT	usDevice;
	ULONG		ulFlashSize;
	ULONG		ulSectorSize;
	ULONG		ulSectorCount;
	USHORT	usOrganization;
	USHORT	usProtectable;
	USHORT	usBufferSize;
	USHORT	usStatus;
} MAX_FLASH_TYPE;

typedef struct _MAX_PDT_HEAD
{
	UCHAR  ucType;
	UCHAR  ucSize;
	USHORT usProcedures;
	USHORT usProgNo;
	CHAR   cVersion;
	CHAR   cRevision;
	UCHAR  ucCPU;
	UCHAR  ucCoProc;
	UCHAR  ucLanguage;
	UCHAR  ucProgType;
	USHORT usFlags;
	USHORT usInterrupt;
	ULONG  ulDataAdr;
	ULONG  ulDataSize;
	ULONG  ulRes1;
	ULONG  ulRes2;
	ULONG  ulParAdr;
	USHORT usParSize;
	ULONG  ulHyperAdr;
	USHORT usRes3;
	ULONG  ulRes4;
} MAX_PDT_HEAD;

typedef struct _MAX_TDT_TYPE
{
	UCHAR  ucType;
	UCHAR  ucSize;
	USHORT usTaskNo;
	USHORT usFlags;
	UCHAR	 ucInterrupt;
	UCHAR	 ucDummy1;
	USHORT usParSize;
	USHORT usProcedures;
	ULONG  ulPDTAddr;
	ULONG  ulHyperAddr;
	ULONG  ulDataStart;
	ULONG  ulDataEnd;
	ULONG  ulDR;
	ULONG  ulDW;
} MAX_TDT_TYPE;

typedef struct _MAX_RAM_TYPE 
{
	ULONG	 ulFree;
	ULONG	 ulTotal;
	ULONG	 ulStart;
	ULONG	 ulEnd;
} MAX_RAM_TYPE;

typedef struct _MAX_TIMER_STATE_TYPE 
{
	USHORT usValue;
	USHORT usMode;
	USHORT usFlags;      // MAX_TIMER_OUTPUT (on/off), MAX_TIMER_MODE (0=bin, 1=dez), MAX_TIMER_ZERO
} MAX_TIMER_STATE_TYPE;

// internal structure used by max_export_handle and max_convert_imported_handle
// do not use/change elements from this structure within a user program  
typedef struct _MAX_CHANNEL_TRANSFER_TYPE 
{
	USHORT	usXSlot;
	USHORT	usSubmodule;
	USHORT	usTask;
	ULONG		ulChannelID;
} MAX_CHANNEL_TRANSFER_TYPE;

typedef struct _MAX_EEPINFO_TYPE 
{
	ULONG		ulVersion;
	ULONG		ulLength;
	ULONG		ulOrg;
	ULONG		ulBufferSize;
	ULONG		ulFlags;
	ULONG		ulSpeed;
} MAX_EEPINFO_TYPE;

// parameter to configure a VIL connection
typedef struct
{
   USHORT      usBoard;
   USHORT      usSlotTransmitter;
   USHORT      usLayerTransmitter;
   USHORT      usSlotReceiver;
   USHORT      usLayerReceiver;
   USHORT      usMode;  // connect/disconnect
   USHORT      usFlags; // properties e.g. exclusiv
} MAX_VIL_CONNECT_TYPE;

typedef struct
{
   USHORT      usIrq;
   USHORT      usXC;
   USHORT      usRAK;
   USHORT      usMode;
} MAX_VIL_RESULT_TYPE;

// opening a file on a compact flash card (for osxfat16.exe driver)
typedef struct
{
	char     acName[80]; // filename with max. 80 chars
   USHORT   usMode;     // file properties
} MAX_FILE_OPEN_TYPE;

// file access on a compact flash card (for osxfat16.exe driver)
typedef struct
{
	ULONG		ulFileHandle;
	ULONG	   ulSize;
	ULONG		ulDataAddr;
   ULONG    ulMode;
} MAX_FILE_WRITE_TYPE, MAX_FILE_READ_TYPE;

// file info on a compact flash card (for osxfat16.exe driver)
typedef struct
{
	char		acName[14];
	ULONG	   ulSize;
	USHORT	usDate;
	USHORT	usTime;
	USHORT	usMode;
	USHORT	usDrive;
	USHORT	usExtra;
} MAX_FILE16_INFO_TYPE;

// info about compact flash card (for osxfat16.exe driver)
typedef struct 
{
	ULONG		ulCapacity;		// total size of the drive in bytes
	ULONG	 	ulFree;			// free size on the drive in bytes
	USHORT	usRootDirSize;	// number of entries in the root directory
	USHORT 	usSectorSize;	// size of one sector in bytes		
	UCHAR 	ucSectorPerCluster; // number of sectors per cluster
	UCHAR 	ucMediaDesc;	// Media descriptor
	USHORT	usFormat;		// type of the file system
	char		aucManufacturer[8];// manufacturer of the drive
} MAX_DRIVE_INFO;

// all structs are word aligned
#ifdef PLATFORM_LINUX           //CB
        #pragma pack(4) //CB
#else                           //CB
        #ifndef __BORLANDC__
                #pragma pack(pop, SORCPACK)
        #else
           #ifndef _RTLIB_
              #pragma option -a8
           #endif
        #endif
#endif                          //CB   

#endif // _INC_X_TYPES_H
